@@ -610,6 +610,14 @@ void Application::printStatus(const ArgumentOccurrence &)
                 statusString = "Remote Syncing";
                 statusColor = "34";
                 break;
+            case SyncthingStatus::NoRemoteConnected:
+                statusString = "No remote device connected";
+                statusColor = "34";
+                break;
+            case SyncthingStatus::Paused:
+                statusString = "At least one device is paused";
+                statusColor = "34";
+                break;
             case SyncthingStatus::Scanning:
                 statusString = "Scanning";
                 statusColor = "34";
@@ -719,7 +727,7 @@ void Application::editConfig(const ArgumentOccurrence &)
 
     // post new config
     cerr << Phrases::Info << "Posting new configuration ..." << TextAttribute::Reset << flush;
-    if (!waitForSignalsOrFail(bind(&SyncthingConnection::postConfigFromByteArray, ref(m_connection), ref(newConfig)), 0,
+    if (!waitForSignalsOrFail([this, &newConfig] { m_connection.postConfigFromByteArray(newConfig); }, 0,
             signalInfo(&m_connection, &SyncthingConnection::error), signalInfo(&m_connection, &SyncthingConnection::newConfigTriggered))) {
         return;
     }
