@@ -5,8 +5,6 @@
 
 #include <syncthingmodel/syncthingicons.h>
 
-#include <qtutilities/misc/desktoputils.h>
-
 #include <KFileItem>
 #include <KPluginFactory>
 
@@ -56,24 +54,19 @@ SyncthingFileItemAction::SyncthingFileItemAction(QObject *parent, const QVariant
 
 QList<QAction *> SyncthingFileItemAction::actions(const KFileItemListProperties &fileItemInfo, QWidget *parentWidget)
 {
-    Q_UNUSED(parentWidget)
-
-    // create actions
-    const QList<QAction *> subActions = createActions(fileItemInfo, this);
-    QList<QAction *> topLevelActions;
+    const auto subActions = createActions(fileItemInfo, this);
 
     // don't show anything if no relevant actions could be determined but successfully connected
     if (s_data.connection().isConnected() && !s_data.hasError() && subActions.isEmpty()) {
-        return topLevelActions;
+        return QList<QAction *>();
     }
 
     if ((m_parentWidget = parentWidget)) {
-        s_data.applyBrightCustomColorsSetting(QtUtilities::isPaletteDark(parentWidget->palette()));
+        s_data.applyBrightCustomColorsSetting(parentWidget->palette());
         parentWidget->installEventFilter(this);
     }
 
-    topLevelActions << new SyncthingMenuAction(fileItemInfo, subActions, parentWidget);
-    return topLevelActions;
+    return QList<QAction *>{ new SyncthingMenuAction(fileItemInfo, subActions, parentWidget) };
 }
 
 struct DirStats {
@@ -128,7 +121,7 @@ QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListPrope
     QList<SyncthingItem> detectedItems;
     const Data::SyncthingDir *lastDir = nullptr;
     for (const Data::SyncthingDir &dir : dirs) {
-        auto dirPath = QDir::cleanPath(dir.path);
+        auto dirPath = QDir::cleanPath(Data::substituteTilde(dir.path, connection.tilde(), connection.pathSeparator()));
         auto dirPathWithSlash = dirPath + QChar('/');
         for (const QString &path : std::as_const(paths)) {
             if (path == dirPath) {
@@ -294,7 +287,7 @@ QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListPrope
 bool SyncthingFileItemAction::eventFilter(QObject *object, QEvent *event)
 {
     if (object == m_parentWidget && event->type() == QEvent::PaletteChange) {
-        s_data.handlePaletteChanged(m_parentWidget->palette());
+        s_data.applyBrightCustomColorsSetting(m_parentWidget->palette());
     }
     return false;
 }
