@@ -211,7 +211,9 @@ QString SyncthingDir::statusString() const
         break;
     case SyncthingDirStatus::Synchronizing:
         if (completionPercentage > 0) {
-            return QCoreApplication::translate("SyncthingDir", "Syncing (%1 %)").arg(completionPercentage);
+            return QCoreApplication::translate("SyncthingDir", "Syncing (%1 %, %2)")
+                .arg(completionPercentage)
+                .arg(dataSizeToString(neededStats.bytes).data());
         }
         break;
     default:;
@@ -258,12 +260,12 @@ SyncthingItemDownloadProgress::SyncthingItemDownloadProgress(
     , bytesAlreadyHandled(values.value(QLatin1String("BytesDone")).toInt())
     , totalNumberOfBytes(values.value(QLatin1String("BytesTotal")).toInt())
     , label(QStringLiteral("%1 / %2 - %3 %")
-                .arg(QString::fromLatin1(
-                         dataSizeToString(blocksAlreadyDownloaded > 0 ? static_cast<std::uint64_t>(blocksAlreadyDownloaded) * syncthingBlockSize : 0)
-                             .data()),
-                    QString::fromLatin1(
-                        dataSizeToString(totalNumberOfBlocks > 0 ? static_cast<std::uint64_t>(totalNumberOfBlocks) * syncthingBlockSize : 0).data()),
-                    QString::number(downloadPercentage)))
+              .arg(QString::fromLatin1(
+                       dataSizeToString(blocksAlreadyDownloaded > 0 ? static_cast<std::uint64_t>(blocksAlreadyDownloaded) * syncthingBlockSize : 0)
+                           .data()),
+                  QString::fromLatin1(
+                      dataSizeToString(totalNumberOfBlocks > 0 ? static_cast<std::uint64_t>(totalNumberOfBlocks) * syncthingBlockSize : 0).data()),
+                  QString::number(downloadPercentage)))
 {
 }
 
@@ -278,6 +280,11 @@ SyncthingStatistics &SyncthingStatistics::operator+=(const SyncthingStatistics &
     return *this;
 }
 
+QString Data::SyncthingStatistics::bytesAsString() const
+{
+    return QString::fromStdString(CppUtilities::dataSizeToString(bytes));
+}
+
 /*!
  * \brief Computes overall statistics for the specified \a directories.
  */
