@@ -14,7 +14,11 @@
 #include <memory>
 #endif
 
-#if !QT_CONFIG(process) && !defined(LIB_SYNCTHING_CONNECTOR_BOOST_PROCESS)
+#if defined(LIB_SYNCTHING_CONNECTOR_NO_PROCESS) || (!QT_CONFIG(process) && !defined(LIB_SYNCTHING_CONNECTOR_BOOST_PROCESS))
+#ifndef LIB_SYNCTHING_CONNECTOR_NO_PROCESS
+#define LIB_SYNCTHING_CONNECTOR_NO_PROCESS
+#endif
+#if !QT_CONFIG(process)
 namespace QProcess {
 enum ProcessError { FailedToStart, Crashed, Timedout, ReadError, WriteError, UnknownError };
 enum ProcessState { NotRunning, Starting, Running };
@@ -24,6 +28,7 @@ enum InputChannelMode { ManagedInputChannel, ForwardedInputChannel };
 enum ExitStatus { NormalExit, CrashExit };
 } // namespace QProcess
 #endif
+#endif
 
 namespace Data {
 
@@ -32,7 +37,7 @@ class SyncthingConnection;
 #define LIB_SYNCTHING_CONNECTOR_PROCESS_IO_DEV_BASED
 struct SyncthingProcessInternalData;
 struct SyncthingProcessIOHandler;
-#elif !QT_CONFIG(process)
+#elif defined(LIB_SYNCTHING_CONNECTOR_NO_PROCESS)
 #define LIB_SYNCTHING_CONNECTOR_PROCESS_IO_DEV_BASED
 #define LIB_SYNCTHING_CONNECTOR_NOOP_PROCESS
 #endif
@@ -58,7 +63,8 @@ public:
     static bool isActiveFor(CppUtilities::DateTime activeSince, unsigned int atLeastSeconds);
     bool isActiveWithoutSleepFor(unsigned int atLeastSeconds) const;
     bool isActiveWithoutSleepFor(CppUtilities::DateTime activeSince, unsigned int atLeastSeconds) const;
-    static bool isActiveWithoutSleepFor(CppUtilities::DateTime lastWakeUp, bool isFallingAsleep, CppUtilities::DateTime activeSince, unsigned int atLeastSeconds);
+    static bool isActiveWithoutSleepFor(
+        CppUtilities::DateTime lastWakeUp, bool isFallingAsleep, CppUtilities::DateTime activeSince, unsigned int atLeastSeconds);
     bool isManuallyStopped() const;
     static SyncthingProcess *mainInstance();
     static void setMainInstance(SyncthingProcess *mainInstance);
@@ -179,7 +185,8 @@ inline bool SyncthingProcess::isActiveWithoutSleepFor(CppUtilities::DateTime act
 
 /// \brief Checks whether a process already runs for the specified number of seconds.
 /// \remarks Considers only the time since the last wakeup if known; otherwise it is identical to isActiveFor().
-inline bool SyncthingProcess::isActiveWithoutSleepFor(CppUtilities::DateTime lastWakeUp, bool isFallingAsleep, CppUtilities::DateTime activeSince, unsigned int atLeastSeconds)
+inline bool SyncthingProcess::isActiveWithoutSleepFor(
+    CppUtilities::DateTime lastWakeUp, bool isFallingAsleep, CppUtilities::DateTime activeSince, unsigned int atLeastSeconds)
 {
     if (!atLeastSeconds) {
         return true;
