@@ -14,10 +14,17 @@ using namespace CppUtilities;
 
 namespace Data {
 
+static int computeDeviceRowCount(const SyncthingDev &dev)
+{
+    // hide connection type, last seen and everything after introducer (eg. traffic) unless connected
+    return dev.isConnected() ? 11 : 6;
+}
+
 SyncthingDeviceModel::SyncthingDeviceModel(SyncthingConnection &connection, QObject *parent)
     : SyncthingModel(connection, parent)
     , m_devs(connection.devInfo())
 {
+    updateRowCount();
     connect(&m_connection, &SyncthingConnection::devStatusChanged, this, &SyncthingDeviceModel::devStatusChanged);
 }
 
@@ -35,6 +42,8 @@ QHash<int, QByteArray> SyncthingDeviceModel::roleNames() const
         { DeviceId, "devId" },
         { DeviceDetail, "detail" },
         { DeviceDetailIcon, "detailIcon" },
+        { DeviceDetailTooltip, "detailTooltip" },
+        { DeviceNeededItemsCount, "neededItemsCount" },
     };
     return roles;
 }
@@ -107,7 +116,11 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
             return QVariant();
         }
         const auto &dev = m_devs[static_cast<size_t>(index.parent().row())];
-        const auto row = !dev.isConnected() && index.row() >= 2 ? index.row() + 2 : index.row();
+        const auto skipRows = !dev.isConnected();
+        auto row = skipRows && index.row() >= 2 ? index.row() + 2 : index.row();
+        if (skipRows && row >= 5) {
+            row += 2;
+        }
         switch (role) {
         case Qt::DisplayRole:
         case Qt::EditRole:
@@ -117,22 +130,24 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
                 case 0:
                     return tr("ID");
                 case 1:
-                    return tr("Address");
+                    return tr("Out of Sync items");
                 case 2:
-                    return tr("Connection type");
-                case 3:
-                    return tr("Last seen");
-                case 4:
-                    return tr("Compression");
-                case 5:
-                    return tr("Certificate");
-                case 6:
-                    return tr("Introducer");
-                case 7:
                     return tr("Incoming traffic");
-                case 8:
+                case 3:
                     return tr("Outgoing traffic");
+                case 4:
+                    return tr("Address");
+                case 5:
+                    return tr("Connection type");
+                case 6:
+                    return tr("Last seen");
+                case 7:
+                    return tr("Compression");
+                case 8:
+                    return tr("Certificate");
                 case 9:
+                    return tr("Introducer");
+                case 10:
                     return tr("Version");
                 }
                 break;
@@ -145,33 +160,40 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
                 case 0:
                     return dev.id;
                 case 1:
+                    if (dev.overallCompletion.needed.isNull()) {
+                        return tr("none");
+                    }
+                    return tr("%1 item(s), ~ %2", nullptr, trQuandity(dev.overallCompletion.needed.items))
+                        .arg(dev.overallCompletion.needed.items)
+                        .arg(dataSizeToString(dev.overallCompletion.needed.bytes).data());
+                case 2:
+                    return QString::fromStdString(dataSizeToString(dev.totalIncomingTraffic));
+                case 3:
+                    return QString::fromStdString(dataSizeToString(dev.totalOutgoingTraffic));
+                case 4:
                     if (dev.connectionAddress.isEmpty()) {
                         return dev.addresses.join(QStringLiteral(", "));
                     } else {
                         return QVariant(
                             dev.connectionAddress % QStringLiteral(" (") % dev.addresses.join(QStringLiteral(", ")) % QStringLiteral(")"));
                     }
-                case 2:
+                case 5:
                     if (!dev.connectionType.isEmpty()) {
                         return QVariant(
                             dev.connectionType % QStringLiteral(" (") % (dev.connectionLocal ? tr("local") : tr("remote")) % QStringLiteral(")"));
                     } else {
                         return QVariant();
                     }
-                case 3:
+                case 6:
                     return dev.lastSeen.isNull() ? tr("unknown or this device")
                                                  : QString::fromLatin1(dev.lastSeen.toString(DateTimeOutputFormat::DateAndTime, true).data());
-                case 4:
-                    return dev.compression;
-                case 5:
-                    return dev.certName.isEmpty() ? tr("none") : dev.certName;
-                case 6:
-                    return dev.introducer ? tr("yes") : tr("no");
                 case 7:
-                    return QString::fromStdString(dataSizeToString(dev.totalIncomingTraffic));
+                    return dev.compression;
                 case 8:
-                    return QString::fromStdString(dataSizeToString(dev.totalOutgoingTraffic));
+                    return dev.certName.isEmpty() ? tr("none") : dev.certName;
                 case 9:
+                    return dev.introducer ? tr("yes") : tr("no");
+                case 10:
                     return dev.clientVersion;
                 }
             }
@@ -185,22 +207,24 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
                 case 0:
                     return icons.hashtag;
                 case 1:
-                    return icons.link;
-                case 2:
                     return icons.exchange;
+                case 2:
+                    return icons.cloudDownload;
                 case 3:
-                    return icons.eye;
+                    return icons.cloudUpload;
                 case 4:
-                    return icons.fileArchive;
+                    return icons.link;
                 case 5:
-                    return icons.certificate;
+                    return icons.signal;
                 case 6:
-                    return icons.networkWired;
+                    return icons.eye;
                 case 7:
-                    return icons.cloudDownloadAlt;
+                    return icons.fileArchive;
                 case 8:
-                    return icons.cloudUploadAlt;
+                    return icons.certificate;
                 case 9:
+                    return icons.networkWired;
+                case 10:
                     return icons.tag;
                 }
             }
@@ -209,12 +233,17 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
             switch (index.column()) {
             case 1:
                 switch (row) {
-                case 3:
+                case 1:
+                    if (dev.overallCompletion.needed.isNull()) {
+                        return Colors::gray(m_brightColors);
+                    }
+                    break;
+                case 6:
                     if (dev.lastSeen.isNull()) {
                         return Colors::gray(m_brightColors);
                     }
                     break;
-                case 5:
+                case 8:
                     if (dev.certName.isEmpty()) {
                         return Colors::gray(m_brightColors);
                     }
@@ -223,15 +252,16 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
             }
             break;
         case Qt::ToolTipRole:
-            switch (index.column()) {
+        case DeviceDetailTooltip:
+            switch ((m_singleColumnMode || role == DeviceDetailTooltip) ? 1 : index.column()) {
             case 1:
                 switch (row) {
-                case 1:
+                case 4:
                     if (!dev.connectionType.isEmpty()) {
                         return dev.connectionType;
                     }
                     break;
-                case 3:
+                case 6:
                     if (!dev.lastSeen.isNull()) {
                         return agoString(dev.lastSeen);
                     }
@@ -312,6 +342,8 @@ QVariant SyncthingDeviceModel::data(const QModelIndex &index, int role) const
         return devStatusColor(dev);
     case DeviceId:
         return dev.id;
+    case DeviceNeededItemsCount:
+        return dev.overallCompletion.needed.items;
     default:;
     }
     return QVariant();
@@ -329,39 +361,60 @@ int SyncthingDeviceModel::rowCount(const QModelIndex &parent) const
 {
     if (!parent.isValid()) {
         return static_cast<int>(m_devs.size());
-    } else if (!parent.parent().isValid()) {
-        // hide connection type, last seen and everything after introducer (eg. traffic) unless connected
-        const auto *const dev(devInfo(parent));
-        return dev && dev->isConnected() ? 10 : 5;
+    } else if (!parent.parent().isValid() && static_cast<std::size_t>(parent.row()) < m_rowCount.size()) {
+        return m_rowCount[static_cast<std::size_t>(parent.row())];
     } else {
         return 0;
     }
 }
 
-int SyncthingDeviceModel::columnCount(const QModelIndex &parent) const
+void SyncthingDeviceModel::devStatusChanged(const SyncthingDev &dev, int index)
 {
-    if (!parent.isValid()) {
-        return 2; // name/id, status
-    } else if (!parent.parent().isValid()) {
-        return 2; // field name and value
-    } else {
-        return 0;
+    if (index < 0 || static_cast<std::size_t>(index) >= m_rowCount.size()) {
+        return;
     }
-}
 
-void SyncthingDeviceModel::devStatusChanged(const SyncthingDev &, int index)
-{
+    // update top-level indices
     const QModelIndex modelIndex1(this->index(index, 0, QModelIndex()));
-    static const QVector<int> modelRoles1({ Qt::DisplayRole, Qt::EditRole, Qt::DecorationRole, DevicePaused, DeviceStatus, DeviceStatusString,
-        DeviceStatusColor, DeviceId, IsThisDevice, IsPinned });
+    static const QVector<int> modelRoles1({ Qt::DisplayRole, Qt::EditRole, Qt::DecorationRole, Qt::ForegroundRole, DevicePaused, DeviceStatus,
+        DeviceStatusString, DeviceStatusColor, DeviceId, IsThisDevice, IsPinned, DeviceNeededItemsCount });
     emit dataChanged(modelIndex1, modelIndex1, modelRoles1);
     const QModelIndex modelIndex2(this->index(index, 1, QModelIndex()));
     static const QVector<int> modelRoles2({ Qt::DisplayRole, Qt::EditRole, Qt::ForegroundRole });
     emit dataChanged(modelIndex2, modelIndex2, modelRoles2);
-    static const QVector<int> modelRoles3({ Qt::DisplayRole, Qt::EditRole, Qt::ToolTipRole });
-    emit dataChanged(this->index(0, 1, modelIndex1), this->index(5, 1, modelIndex1), modelRoles3);
-    static const QVector<int> modelRoles4({ Qt::DisplayRole, Qt::EditRole, DeviceDetail });
-    emit dataChanged(this->index(0, 0, modelIndex1), this->index(5, 0, modelIndex1), modelRoles4);
+
+    // remove/insert detail rows
+    const auto oldRowCount = m_rowCount[static_cast<std::size_t>(index)];
+    const auto newRowCount = computeDeviceRowCount(dev);
+    const auto newLastRow = newRowCount - 1;
+    if (oldRowCount > newRowCount) {
+        // begin removing rows for statistics
+        beginRemoveRows(modelIndex1, 2, 3);
+        m_rowCount[static_cast<std::size_t>(index)] = newRowCount;
+        endRemoveRows();
+    } else if (newRowCount > oldRowCount) {
+        // begin inserting rows for statistics
+        beginInsertRows(modelIndex1, 2, 3);
+        m_rowCount[static_cast<std::size_t>(index)] = newRowCount;
+        endInsertRows();
+    }
+
+    // update detail rows
+    static const QVector<int> modelRoles3({ Qt::DisplayRole, Qt::EditRole, Qt::ToolTipRole, DeviceDetailTooltip });
+    emit dataChanged(this->index(0, 1, modelIndex1), this->index(newLastRow, 1, modelIndex1), modelRoles3);
+    static const QVector<int> modelRoles4({ Qt::DisplayRole, Qt::EditRole, DeviceDetail, DeviceDetailIcon });
+    emit dataChanged(this->index(0, 0, modelIndex1), this->index(newLastRow, 0, modelIndex1), modelRoles4);
+}
+
+void SyncthingDeviceModel::handleConfigInvalidated()
+{
+    beginResetModel();
+}
+
+void SyncthingDeviceModel::handleNewConfigAvailable()
+{
+    updateRowCount();
+    endResetModel();
 }
 
 void SyncthingDeviceModel::handleStatusIconsChanged()
@@ -396,4 +449,13 @@ QVariant SyncthingDeviceModel::devStatusColor(const SyncthingDev &dev) const
     return QVariant();
 }
 
+void SyncthingDeviceModel::updateRowCount()
+{
+    m_rowCount.clear();
+    m_rowCount.reserve(m_devs.size());
+    for (const auto &dev : m_devs) {
+        m_rowCount.emplace_back(computeDeviceRowCount(dev));
+    }
+}
+
 } // namespace Data
