@@ -16,7 +16,7 @@ namespace Data {
 
 static int computeDirectoryRowCount(const SyncthingDir &dir)
 {
-    return dir.paused ? 8 : 10;
+    return dir.paused ? 8 : 11;
 }
 
 SyncthingDirectoryModel::SyncthingDirectoryModel(SyncthingConnection &connection, QObject *parent)
@@ -41,6 +41,10 @@ QHash<int, QByteArray> SyncthingDirectoryModel::roleNames() const
         { DirectoryPullErrorCount, "pullErrorCount" },
         { DirectoryDetail, "detail" },
         { DirectoryDetailIcon, "detailIcon" },
+        { DirectoryDetailTooltip, "detailTooltip" },
+        { DirectoryNeededItemsCount, "neededItemsCount" },
+        { DirectoryOverrideRevertAction, "overrideRevertAction" },
+        { DirectoryOverrideRevertActionLabel, "overrideRevertActionLabel" },
     };
     return roles;
 }
@@ -139,7 +143,9 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
                 case 8:
                     return tr("Last file");
                 case 9:
-                    return tr("Errors");
+                    return tr("Out of Sync items");
+                case 10:
+                    return tr("Failed items");
                 }
                 break;
             }
@@ -174,6 +180,13 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
                 case 8:
                     return dir.lastFileName.isEmpty() ? tr("unknown") : dir.lastFileName;
                 case 9:
+                    if (dir.neededStats.isNull()) {
+                        return tr("none");
+                    }
+                    return tr("%1 item(s), ~ %2", nullptr, trQuandity(dir.neededStats.total))
+                        .arg(dir.neededStats.total)
+                        .arg(dataSizeToString(dir.neededStats.bytes).data());
+                case 10:
                     if (dir.globalError.isEmpty() && !dir.pullErrorCount) {
                         return tr("none");
                     }
@@ -181,9 +194,9 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
                         return dir.globalError;
                     }
                     if (dir.globalError.isEmpty()) {
-                        return tr("%1 item(s) out of sync", nullptr, trQuandity(dir.pullErrorCount)).arg(dir.pullErrorCount);
+                        return tr("%1 item(s)", nullptr, trQuandity(dir.pullErrorCount)).arg(dir.pullErrorCount);
                     }
-                    return tr("%1 and %2 item(s) out of sync", nullptr, trQuandity(dir.pullErrorCount)).arg(dir.globalError).arg(dir.pullErrorCount);
+                    return tr("%1 and %2 item(s)", nullptr, trQuandity(dir.pullErrorCount)).arg(dir.globalError).arg(dir.pullErrorCount);
                 }
             }
             break;
@@ -210,9 +223,11 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
                 case 7:
                     return icons.clock;
                 case 8:
-                    return icons.exchangeAlt;
+                    return icons.exchange;
                 case 9:
-                    return icons.exclamationTriangle;
+                    return icons.cloudDownload;
+                case 10:
+                    return icons.exclamationCircle;
                 }
             }
             break;
@@ -234,12 +249,15 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
                     return dir.lastFileName.isEmpty() ? Colors::gray(m_brightColors)
                                                       : (dir.lastFileDeleted ? Colors::red(m_brightColors) : QVariant());
                 case 9:
+                    return dir.neededStats.total == 0 ? Colors::gray(m_brightColors) : Colors::red(m_brightColors);
+                case 10:
                     return dir.globalError.isEmpty() && !dir.pullErrorCount ? Colors::gray(m_brightColors) : Colors::red(m_brightColors);
                 }
             }
             break;
         case Qt::ToolTipRole:
-            switch (index.column()) {
+        case DirectoryDetailTooltip:
+            switch ((m_singleColumnMode || role == DirectoryDetailTooltip) ? 1 : index.column()) {
             case 1:
                 switch (row) {
                 case 3:
@@ -265,9 +283,9 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
                         }
                     }
                     break;
-                case 9:
+                case 10:
                     if (!dir.itemErrors.empty()) {
-                        QStringList errors;
+                        auto errors = QStringList();
                         errors.reserve(static_cast<int>(dir.itemErrors.size()));
                         for (const auto &error : dir.itemErrors) {
                             errors << error.path;
@@ -358,6 +376,28 @@ QVariant SyncthingDirectoryModel::data(const QModelIndex &index, int role) const
         return dir.path;
     case DirectoryPullErrorCount:
         return dir.pullErrorCount;
+    case DirectoryNeededItemsCount:
+        return dir.neededStats.total;
+    case DirectoryOverrideRevertAction:
+        switch (dir.dirType) {
+        case SyncthingDirType::SendOnly:
+            return dir.isOutOfSync() ? QStringLiteral("override") : QString();
+        case SyncthingDirType::ReceiveOnly:
+        case SyncthingDirType::ReceiveEncrypted:
+            return dir.receiveOnlyStats.total ? QStringLiteral("revert") : QString();
+        default:
+            return QString();
+        }
+    case DirectoryOverrideRevertActionLabel:
+        switch (dir.dirType) {
+        case SyncthingDirType::SendOnly:
+            return dir.isOutOfSync() ? tr("Override remote changes") : QString();
+        case SyncthingDirType::ReceiveOnly:
+        case SyncthingDirType::ReceiveEncrypted:
+            return dir.receiveOnlyStats.total ? tr("Revert local changes") : QString();
+        default:
+            return QString();
+        }
     default:;
     }
 
@@ -376,19 +416,8 @@ int SyncthingDirectoryModel::rowCount(const QModelIndex &parent) const
 {
     if (!parent.isValid()) {
         return static_cast<int>(m_dirs.size());
-    } else if (!parent.parent().isValid() && static_cast<size_t>(parent.row()) < m_rowCount.size()) {
-        return m_rowCount[static_cast<size_t>(parent.row())];
-    } else {
-        return 0;
-    }
-}
-
-int SyncthingDirectoryModel::columnCount(const QModelIndex &parent) const
-{
-    if (!parent.isValid()) {
-        return 2; // label/ID, status/buttons
-    } else if (!parent.parent().isValid()) {
-        return 2; // field name and value
+    } else if (!parent.parent().isValid() && static_cast<std::size_t>(parent.row()) < m_rowCount.size()) {
+        return m_rowCount[static_cast<std::size_t>(parent.row())];
     } else {
         return 0;
     }
@@ -396,37 +425,38 @@ int SyncthingDirectoryModel::columnCount(const QModelIndex &parent) const
 
 void SyncthingDirectoryModel::dirStatusChanged(const SyncthingDir &dir, int index)
 {
-    if (index < 0 || static_cast<size_t>(index) >= m_rowCount.size()) {
+    if (index < 0 || static_cast<std::size_t>(index) >= m_rowCount.size()) {
         return;
     }
 
-    // update top-level indizes
+    // update top-level indices
     const QModelIndex modelIndex1(this->index(index, 0, QModelIndex()));
     static const QVector<int> modelRoles1({ Qt::DisplayRole, Qt::EditRole, Qt::DecorationRole, DirectoryPaused, DirectoryStatus,
-        DirectoryStatusString, DirectoryStatusColor, DirectoryId, DirectoryPath, DirectoryPullErrorCount });
+        DirectoryStatusString, DirectoryStatusColor, DirectoryId, DirectoryPath, DirectoryPullErrorCount, DirectoryNeededItemsCount,
+        DirectoryOverrideRevertAction, DirectoryOverrideRevertActionLabel });
     emit dataChanged(modelIndex1, modelIndex1, modelRoles1);
     const QModelIndex modelIndex2(this->index(index, 1, QModelIndex()));
     static const QVector<int> modelRoles2({ Qt::DisplayRole, Qt::EditRole, Qt::ForegroundRole });
     emit dataChanged(modelIndex2, modelIndex2, modelRoles2);
 
     // remove/insert detail rows
-    const auto oldRowCount = m_rowCount[static_cast<size_t>(index)];
+    const auto oldRowCount = m_rowCount[static_cast<std::size_t>(index)];
     const auto newRowCount = computeDirectoryRowCount(dir);
     const auto newLastRow = newRowCount - 1;
     if (oldRowCount > newRowCount) {
         // begin removing rows for statistics
         beginRemoveRows(modelIndex1, 2, 3);
-        m_rowCount[static_cast<size_t>(index)] = newRowCount;
+        m_rowCount[static_cast<std::size_t>(index)] = newRowCount;
         endRemoveRows();
     } else if (newRowCount > oldRowCount) {
         // begin inserting rows for statistics
         beginInsertRows(modelIndex1, 2, 3);
-        m_rowCount[static_cast<size_t>(index)] = newRowCount;
+        m_rowCount[static_cast<std::size_t>(index)] = newRowCount;
         endInsertRows();
     }
 
     // update detail rows
-    static const QVector<int> modelRoles3({ Qt::DisplayRole, Qt::EditRole, Qt::ToolTipRole });
+    static const QVector<int> modelRoles3({ Qt::DisplayRole, Qt::EditRole, Qt::ToolTipRole, DirectoryDetailTooltip });
     emit dataChanged(this->index(0, 1, modelIndex1), this->index(newLastRow, 1, modelIndex1), modelRoles3);
     static const QVector<int> modelRoles4({ Qt::DisplayRole, Qt::EditRole, DirectoryDetail });
     emit dataChanged(this->index(0, 0, modelIndex1), this->index(newLastRow, 0, modelIndex1), modelRoles4);
