@@ -10,15 +10,20 @@
 #include <qtutilities/misc/desktoputils.h>
 
 #include <c++utilities/conversion/stringconversion.h>
+#include <c++utilities/io/path.h>
 
 #include <QClipboard>
+#include <QFile>
 #include <QGuiApplication>
+#include <QMetaObject>
 #include <QNetworkReply>
 #include <QPainter>
 #include <QStringBuilder>
+#include <QThreadPool>
 #include <QtConcurrent>
 
 #include <cassert>
+#include <filesystem>
 #include <limits>
 #include <utility>
 
@@ -84,13 +89,14 @@ SyncthingFileModel::SyncthingFileModel(SyncthingConnection &connection, const Sy
     connect(this, &SyncthingFileModel::hasStagedChangesChanged, this, &SyncthingFileModel::selectionActionsChanged);
     if (m_connection.isLocal()) {
         m_root->existsLocally = true;
-        m_localPath = dir.pathWithoutTrailingSlash().toString();
+        m_localPath = Data::substituteTilde(dir.pathWithoutTrailingSlash().toString(), m_connection.tilde(), m_connection.pathSeparator());
         m_columns += 1;
         connect(&m_localItemLookup, &QFutureWatcherBase::finished, this, &SyncthingFileModel::handleLocalLookupFinished);
     }
     m_pathSeparator = m_connection.pathSeparator().size() == 1 ? m_connection.pathSeparator().front() : QDir::separator();
     m_ignoreAllByDefaultPattern = m_pathSeparator + QStringLiteral("**");
     m_root->name = dir.displayName();
+    m_root->existsInDb = true;
     m_root->modificationTime = dir.lastFileTime;
     m_root->size = dir.globalStats.bytes;
     m_root->type = SyncthingItemType::Directory;
@@ -222,12 +228,16 @@ QString SyncthingFileModel::computeIgnorePatternDiff()
 
 QString SyncthingFileModel::availabilityNote(const SyncthingItem *item) const
 {
-    if (item->existsInDb && item->existsLocally) {
+    if (item->existsInDb.value_or(false) && item->existsLocally.value_or(false)) {
         return tr("Exists locally and globally");
-    } else if (item->existsInDb) {
+    } else if (item->existsInDb.value_or(false) && item->existsLocally.has_value()) {
         return tr("Exists only globally");
-    } else if (item->existsLocally) {
+    } else if (item->existsLocally.value_or(false) && item->existsInDb.has_value()) {
         return tr("Exists only locally");
+    } else if (item->existsInDb.value_or(false)) {
+        return tr("Exists globally and perhaps locally");
+    } else if (item->existsLocally.value_or(false)) {
+        return tr("Exists locally and perhaps globally");
     } else {
         return tr("Does not exist");
     }
@@ -268,6 +278,20 @@ void SyncthingFileModel::editIgnorePatternsManually(const QString &ignorePattern
     m_manuallyEditedIgnorePatterns = ignorePatterns;
 }
 
+void SyncthingFileModel::editLocalDeletions(const QSet<QString> &localDeletions)
+{
+    m_manuallyEditedLocalDeletions = localDeletions;
+}
+
+void SyncthingFileModel::editLocalDeletionsFromVariantList(const QVariantList &localDeletions)
+{
+    m_manuallyEditedLocalDeletions.emplace();
+    m_manuallyEditedLocalDeletions->reserve(localDeletions.size());
+    for (const auto &path : localDeletions) {
+        m_manuallyEditedLocalDeletions->insert(path.toString());
+    }
+}
+
 QModelIndex SyncthingFileModel::parent(const QModelIndex &child) const
 {
     if (!child.isValid()) {
@@ -390,7 +414,7 @@ QVariant SyncthingFileModel::data(const QModelIndex &index, int role) const
             }
             break;
         case 4: {
-            auto &icon = m_statusIcons[(item->existsInDb ? 0x01 : 0x00) | (item->existsLocally ? 0x02 : 0x00)];
+            auto &icon = m_statusIcons[(item->existsInDb.value_or(false) ? 0x01 : 0x00) | (item->existsLocally.value_or(false) ? 0x02 : 0x00)];
             if (icon.isNull()) {
                 static constexpr auto size = 16;
                 icon = QPixmap(size * 2, size);
@@ -398,11 +422,11 @@ QVariant SyncthingFileModel::data(const QModelIndex &index, int role) const
                 auto &manager = IconManager::instance();
                 auto painter = QPainter(&icon);
                 auto left = 0;
-                if (item->existsInDb) {
+                if (item->existsInDb.value_or(false)) {
                     manager.renderForkAwesomeIcon(QtForkAwesome::Icon::Globe, &painter, QRect(left, 0, size, size));
                 }
                 left += size;
-                if (item->existsLocally) {
+                if (item->existsLocally.value_or(false)) {
                     manager.renderForkAwesomeIcon(QtForkAwesome::Icon::Home, &painter, QRect(left, 0, size, size));
                 }
             }
@@ -412,7 +436,7 @@ QVariant SyncthingFileModel::data(const QModelIndex &index, int role) const
         break;
     }
     case Qt::ForegroundRole:
-        if (!item->existsInDb) {
+        if (!item->existsInDb.value_or(false)) {
             return Colors::gray(m_brightColors);
         }
         break;
@@ -437,7 +461,7 @@ QVariant SyncthingFileModel::data(const QModelIndex &index, int role) const
     case SizeRole:
         return static_cast<qsizetype>(item->size);
     case ModificationTimeRole:
-        return QString::fromStdString(item->modificationTime.toString());
+        return item->modificationTime.isNull() ? QString() : QString::fromStdString(item->modificationTime.toString());
     case PathRole:
         return item->isFilesystemItem() ? item->path : QString();
     case Actions: {
@@ -495,8 +519,9 @@ QVariant SyncthingFileModel::data(const QModelIndex &index, int role) const
         default:
             return QString();
         }
-        auto res
-            = QString(availabilityNote(item) % QStringLiteral("\nLast modified on: ") % QString::fromStdString(item->modificationTime.toString()));
+        auto res = QString(availabilityNote(item)
+            % (item->modificationTime.isNull() ? QString()
+                                               : QStringLiteral("\nLast modified on: ") % QString::fromStdString(item->modificationTime.toString())));
         if (item->ignorePattern == SyncthingItem::ignorePatternNotInitialized) {
             matchItemAgainstIgnorePatterns(*item);
         }
@@ -673,9 +698,9 @@ template <typename Callback> static void forEachItem(SyncthingItem *root, Callba
     }
 }
 
-void SyncthingFileModel::ignoreSelectedItems(bool ignore)
+void SyncthingFileModel::ignoreSelectedItems(bool ignore, bool deleteLocally)
 {
-    forEachItem(m_root.get(), [this, ignore](const SyncthingItem *item) {
+    forEachItem(m_root.get(), [this, ignore, deleteLocally](const SyncthingItem *item) {
         if (item->checked != Qt::Checked || !item->isFilesystemItem()) {
             return true;
         }
@@ -732,6 +757,13 @@ void SyncthingFileModel::ignoreSelectedItems(bool ignore)
             insertPattern(m_stagedChanges[m_presentIgnorePatterns.size() - 1].append, wantedPattern, path);
         }
 
+        // stage deletion of local file
+        if (deleteLocally) {
+            m_stagedLocalFileDeletions.insert(item->path);
+        } else {
+            m_stagedLocalFileDeletions.remove(item->path);
+        }
+
         // prepend the new pattern making sure it is effective and not shadowed by an existing pattern
         return false; // no need to add ignore patterns for children as they are applied recursively anyway
     });
@@ -741,10 +773,11 @@ void SyncthingFileModel::ignoreSelectedItems(bool ignore)
 QList<QAction *> SyncthingFileModel::selectionActions()
 {
     auto res = QList<QAction *>();
-    res.reserve(8);
+    res.reserve(9);
     if (!m_selectionMode) {
         auto *const startSelectionAction = new QAction(tr("Select items to sync/ignore"), this);
         startSelectionAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-select")));
+        startSelectionAction->setData(QStringLiteral("primary:") + tr("Select"));
         connect(startSelectionAction, &QAction::triggered, this, [this] { setSelectionModeEnabled(true); });
         res << startSelectionAction;
 
@@ -759,8 +792,9 @@ QList<QAction *> SyncthingFileModel::selectionActions()
             res << discardAction;
         }
     } else {
-        auto *const discardAction = new QAction(tr("Discard selection and staged changes"), this);
+        auto *const discardAction = new QAction(tr("Uncheck all and discard staged changes"), this);
         discardAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
+        discardAction->setData(QStringLiteral("primary:") + tr("Discard"));
         connect(discardAction, &QAction::triggered, this, [this] {
             if (const auto rootIndex = index(0, 0); rootIndex.isValid()) {
                 setCheckState(index(0, 0), Qt::Unchecked, true);
@@ -772,13 +806,23 @@ QList<QAction *> SyncthingFileModel::selectionActions()
         });
         res << discardAction;
 
-        auto *const ignoreSelectedAction = new QAction(tr("Ignore selected items (and their children)"), this);
+        auto *const ignoreSelectedAction = new QAction(tr("Ignore checked items (and their children)"), this);
         ignoreSelectedAction->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
+        ignoreSelectedAction->setData(QStringLiteral("ignore"));
         connect(ignoreSelectedAction, &QAction::triggered, this, [this]() { ignoreSelectedItems(); });
         res << ignoreSelectedAction;
 
-        auto *const includeSelectedAction = new QAction(tr("Include selected items (and their children)"), this);
+        if (!m_localPath.isEmpty()) {
+            auto *const ignoreAndDeleteSelectedAction = new QAction(tr("Ignore and locally delete checked items (and their children)"), this);
+            ignoreAndDeleteSelectedAction->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
+            ignoreAndDeleteSelectedAction->setData(QStringLiteral("ignore"));
+            connect(ignoreAndDeleteSelectedAction, &QAction::triggered, this, [this]() { ignoreSelectedItems(true, true); });
+            res << ignoreAndDeleteSelectedAction;
+        }
+
+        auto *const includeSelectedAction = new QAction(tr("Include checked items (and their children)"), this);
         includeSelectedAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
+        includeSelectedAction->setData(QStringLiteral("include"));
         connect(includeSelectedAction, &QAction::triggered, this, [this]() { ignoreSelectedItems(false); });
         res << includeSelectedAction;
     }
@@ -786,6 +830,7 @@ QList<QAction *> SyncthingFileModel::selectionActions()
     auto *const ignoreByDefaultAction
         = new QAction(m_isIgnoringAllByDefault ? tr("Include all items by default") : tr("Ignore all items by default"), this);
     ignoreByDefaultAction->setIcon(QIcon::fromTheme(QStringLiteral("question")));
+    ignoreByDefaultAction->setData(m_isIgnoringAllByDefault ? QStringLiteral("include") : QStringLiteral("ignore"));
     connect(ignoreByDefaultAction, &QAction::triggered, this, [this, isIgnoringAllByDefault = m_isIgnoringAllByDefault]() {
         auto &lastLine = m_stagedChanges[m_presentIgnorePatterns.size() - 1];
         if (isIgnoringAllByDefault) {
@@ -814,7 +859,7 @@ QList<QAction *> SyncthingFileModel::selectionActions()
 
     if (m_selectionMode) {
         auto *const removeIgnorePatternsAction
-            = new QAction(tr("Remove ignore patterns matching against selected items (may affect other items as well)"), this);
+            = new QAction(tr("Remove ignore patterns matching checked items (may affect other items as well)"), this);
         removeIgnorePatternsAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
         connect(removeIgnorePatternsAction, &QAction::triggered, this, [this]() {
             forEachItem(m_root.get(), [this](SyncthingItem *item) {
@@ -844,12 +889,15 @@ QList<QAction *> SyncthingFileModel::selectionActions()
     if (!m_stagedChanges.isEmpty() || !m_stagedLocalFileDeletions.isEmpty()) {
         auto *const applyStagedChangesAction = new RejectableAction(tr("Review and apply staged changes"), this);
         applyStagedChangesAction->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")));
+        applyStagedChangesAction->setData(QStringLiteral("primary:") + tr("Apply"));
         connect(applyStagedChangesAction, &QAction::triggered, this, [this, action = applyStagedChangesAction]() mutable {
             // allow user to review changes before applying them
             if (action->needsConfirmation) {
                 action->needsConfirmation = false;
                 m_manuallyEditedIgnorePatterns.clear();
-                emit actionNeedsConfirmation(action, tr("Do you want to apply the following changes?"), computeIgnorePatternDiff());
+                m_manuallyEditedLocalDeletions.reset();
+                emit actionNeedsConfirmation(
+                    action, tr("Do you want to apply the following changes?"), computeIgnorePatternDiff(), m_stagedLocalFileDeletions);
                 return;
             }
             action->needsConfirmation = true;
@@ -871,7 +919,6 @@ QList<QAction *> SyncthingFileModel::selectionActions()
 
                 // reset state and query ignore patterns again on success so matching ignore patterns are updated
                 m_stagedChanges.clear();
-                m_stagedLocalFileDeletions.clear();
                 m_hasIgnorePatterns = false;
                 forEachItem(m_root.get(), [](SyncthingItem *item) {
                     item->ignorePattern = SyncthingItem::ignorePatternNotInitialized;
@@ -879,8 +926,45 @@ QList<QAction *> SyncthingFileModel::selectionActions()
                 });
                 queryIgnores();
 
-                emit notification(QStringLiteral("info"), tr("Ignore patterns have been changed."));
-                emit hasStagedChangesChanged(hasStagedChanges());
+                // conclude immediately if there are no local deletions to do
+                const auto &localDeletions = m_manuallyEditedLocalDeletions.value_or(m_stagedLocalFileDeletions);
+                if (localDeletions.isEmpty()) {
+                    return concludeApplyingChanges();
+                }
+
+                // delete local files/directories staged for deletion
+                QThreadPool::globalInstance()->start([this, localDeletions, basePath = m_localPath + m_pathSeparator] {
+                    auto successfulDeletions = QStringList(), failedDeletions = QStringList();
+                    for (const auto &path : localDeletions) {
+                        const auto fullPath = basePath + path;
+#ifdef Q_OS_WINDOWS
+                        const auto fullNativePath = NativePathStringView(
+                            reinterpret_cast<const PathValueType *>(fullPath.utf16()), static_cast<std::size_t>(fullPath.size()));
+#else
+                        const auto fullPathUtf8 = fullPath.toUtf8();
+                        const auto fullNativePath = NativePathStringView(fullPathUtf8.data(), static_cast<std::size_t>(fullPathUtf8.size()));
+#endif
+                        const auto fullStdPath = std::filesystem::path(fullNativePath);
+#ifdef Q_OS_ANDROID
+                        // do normal deletion on Android as it has no standardized trash
+                        auto ec = std::error_code();
+                        std::filesystem::remove_all(fullStdPath, ec);
+                        if (ec) {
+                            failedDeletions.append(fullPath % QChar(':') % QChar(' ') % QString::fromStdString(ec.message()));
+                            continue;
+                        }
+#else
+                        // move item to trash instead of actually deleting it as this is probably more appropriate for a GUI app
+                        if (std::filesystem::exists(fullStdPath) && !QFile::moveToTrash(fullPath)) {
+                            failedDeletions.append(fullPath);
+                            continue;
+                        }
+#endif
+                        successfulDeletions.append(path);
+                    }
+                    QMetaObject::invokeMethod(
+                        this, "concludeApplyingChanges", Q_ARG(QStringList, successfulDeletions), Q_ARG(QStringList, failedDeletions));
+                });
             });
         });
         res << applyStagedChangesAction;
@@ -889,6 +973,20 @@ QList<QAction *> SyncthingFileModel::selectionActions()
     return res;
 }
 
+void SyncthingFileModel::concludeApplyingChanges(const QStringList &successfulDeletions, const QStringList &failedDeletions)
+{
+    for (const auto &file : successfulDeletions) {
+        m_stagedLocalFileDeletions.remove(file);
+    }
+    if (failedDeletions.isEmpty()) {
+        emit notification(QStringLiteral("info"), tr("Ignore patterns have been changed."));
+    } else {
+        emit notification(QStringLiteral("error"),
+            tr("Ignore patterns have been changed but the following local files could not be deleted:\n") + failedDeletions.join(QChar('\n')));
+    }
+    emit hasStagedChangesChanged(hasStagedChanges());
+}
+
 void SyncthingFileModel::setSelectionModeEnabled(bool selectionModeEnabled)
 {
     if (m_selectionMode != selectionModeEnabled) {
@@ -925,7 +1023,6 @@ void SyncthingFileModel::lookupDirLocally(const QDir &dir, SyncthingFileModel::L
         const auto entryName = entry.fileName();
         auto &item = items[entryName];
         item.name = entryName;
-        item.existsInDb = false;
         item.existsLocally = true;
         item.size = static_cast<std::size_t>(entry.size());
         item.modificationTime = DateTime::unixEpochStart() + TimeSpan(TimeSpan::ticksPerMillisecond * entry.lastModified().toMSecsSinceEpoch());
@@ -979,7 +1076,7 @@ void SyncthingFileModel::processFetchQueue(const QString &lastItemPath)
     }
 
     // query directory entries from Syncthing database
-    if (rootItem->existsInDb) {
+    if (rootItem->existsInDb.value_or(false)) {
         m_pendingRequest = m_connection.browse(
             m_dirId, path, 1, [this, populated](std::vector<std::unique_ptr<SyncthingItem>> &&items, QString &&errorMessage) mutable {
                 m_pendingRequest.reply = nullptr;
@@ -1006,6 +1103,7 @@ void SyncthingFileModel::processFetchQueue(const QString &lastItemPath)
                     beginInsertRows(
                         refreshedIndex, 0, last < std::numeric_limits<int>::max() ? static_cast<int>(last) : std::numeric_limits<int>::max());
                     refreshedItem->children = std::move(items);
+                    forEachItem(refreshedItem, [](SyncthingItem *item) { return item->existsInDb.emplace(true); });
                     switch (refreshedItem->checked) {
                     case Qt::Checked:
                         if (m_recursiveSelectionEnabled) {
@@ -1045,7 +1143,7 @@ void SyncthingFileModel::processFetchQueue(const QString &lastItemPath)
         lookupDirLocally(dir, *items);
         return items;
     });
-    if (!rootItem->existsInDb) {
+    if (!rootItem->existsInDb.value_or(false)) {
         m_pendingRequest.refreshedIndex = rootIndex;
         m_localItemLookup.setFuture(m_pendingRequest.localLookup);
     }
@@ -1109,11 +1207,14 @@ void SyncthingFileModel::markItemsFromDatabaseAsLocallyExisting(
     std::vector<std::unique_ptr<SyncthingItem>> &items, SyncthingFileModel::LocalItemMap &localItems)
 {
     for (auto &child : items) {
-        auto localItemIter = localItems.find(child->name);
-        if (localItemIter == localItems.end()) {
+        const auto localItemIter = localItems.find(child->name);
+        const auto itemExists = localItemIter != localItems.end();
+        child->existsLocally = itemExists;
+        if (!itemExists) {
+            static auto noLocalChildren = SyncthingFileModel::LocalItemMap();
+            markItemsFromDatabaseAsLocallyExisting(child->children, noLocalChildren);
             continue;
         }
-        child->existsLocally = true;
         localItemIter->second.existsInDb = child->existsInDb;
         localItemIter->second.index = child->index;
         markItemsFromDatabaseAsLocallyExisting(child->children, localItemIter->second.localChildren);
@@ -1128,14 +1229,15 @@ void SyncthingFileModel::insertLocalItems(const QModelIndex &refreshedIndex, Syn
     // get refreshed index/item
     auto *const refreshedItem = reinterpret_cast<SyncthingItem *>(refreshedIndex.internalPointer());
     auto &items = refreshedItem->children;
+    const auto hasDbItems = !items.empty() && items.front()->type != SyncthingItemType::Error;
     const auto previouslyPopulated = refreshedItem->childrenPopulated;
     const auto previousChildCount = items.size();
-    if (!refreshedItem->existsInDb) {
+    if (!refreshedItem->existsInDb.value_or(false)) {
         refreshedItem->childrenPopulated = true;
     }
 
     // clear loading item
-    if (!refreshedItem->existsInDb && !items.empty()) {
+    if (!refreshedItem->existsInDb.value_or(false) && !items.empty()) {
         const auto last = items.size() - 1;
         beginRemoveRows(refreshedIndex, 0, last < std::numeric_limits<int>::max() ? static_cast<int>(last) : std::numeric_limits<int>::max());
         items.clear();
@@ -1147,13 +1249,16 @@ void SyncthingFileModel::insertLocalItems(const QModelIndex &refreshedIndex, Syn
     auto row = index < std::numeric_limits<int>::max() ? static_cast<int>(index) : std::numeric_limits<int>::max();
     auto firstRow = row;
     for (auto &[localItemName, localItem] : localItems) {
-        if (localItem.existsInDb) {
+        if (localItem.existsInDb.value_or(false)) {
             continue;
         }
         beginInsertRows(refreshedIndex, row, row);
         auto &item = items.emplace_back(std::make_unique<SyncthingItem>(std::move(localItem)));
         item->parent = refreshedItem;
         item->index = localItem.index = index++;
+        if (hasDbItems) {
+            item->existsInDb = false;
+        }
         switch (refreshedItem->checked) {
         case Qt::Checked:
             if (m_recursiveSelectionEnabled) {
