@@ -17,6 +17,13 @@
 #include <QStringBuilder>
 #include <QSvgRenderer>
 
+#ifdef Q_OS_ANDROID
+#include <QJniEnvironment>
+#include <QJniObject>
+
+#include <android/bitmap.h>
+#endif
+
 #ifndef LIB_SYNCTHING_MODEL_STATIC
 ENABLE_QT_RESOURCES_OF_STATIC_DEPENDENCIES
 #endif
@@ -89,8 +96,8 @@ QByteArray makeSyncthingIcon(const StatusIconColorSet &colors, StatusEmblem stat
         ),
         QStringLiteral(
             "<circle id=\"bubble\" cx=\"11.5\" cy=\"11.5\" r=\"4.5\" style=\"fill:#000000\"/>"
-            "<g id=\"plus\">"
-                "<path style=\"fill:#fffff6;fill-opacity:1;stroke:none;stroke-width:0.48022598\" d=\"m 10.771186,8.4407554 c -1.1972026,0 -2.1610164,0.9652542 -2.1610164,2.1610166 0,1.197203 0.9652547,2.161017 2.1610164,2.161017 0.510789,0 0.973102,-0.183061 1.342194,-0.477411 l 1.919966,1.919965 0.339535,-0.339535 -1.919965,-1.919966 c 0.29565,-0.369668 0.479287,-0.832466 0.479287,-1.34407 0,-1.197203 -0.965254,-2.1610166 -2.161017,-2.1610166 z m 0,0.480226 c 0.931159,0 1.680791,0.7496332 1.680791,1.6807906 0,0.931159 -0.749632,1.680791 -1.680791,1.680791 -0.9311583,0 -1.6807905,-0.749632 -1.6807905,-1.680791 0,-0.9311574 0.7496322,-1.6807906 1.6807905,-1.6807906 z\"/>"
+            "<g id=\"cross\">"
+                "<path style=\"fill:#fffff6;fill-opacity:1;stroke:none;;stroke-width:1.01088\" d=\"M 9.819813,8.937 8.937,9.819813 10.616688,11.4995 8.937,13.179187 9.821766,14.062 11.501454,12.384266 13.179189,14.062 14.063954,13.179188 12.384267,11.4995 14.063954,9.819813 13.179188,8.937 11.499501,10.616687 Z\"/>"
             "</g>"
         ),
     };
@@ -300,6 +307,8 @@ StatusIcons::StatusIcons(const StatusIconSettings &settings)
     , error(QIcon(renderSvgImage(makeSyncthingIcon(settings.errorColor, StatusEmblem::Alert, settings.strokeWidth), settings.renderSize)))
     , errorSync(QIcon(renderSvgImage(makeSyncthingIcon(settings.errorColor, StatusEmblem::Synchronizing, settings.strokeWidth), settings.renderSize)))
     , newItem(QIcon(renderSvgImage(makeSyncthingIcon(settings.defaultColor, StatusEmblem::Add, settings.strokeWidth), settings.renderSize)))
+    , noRemoteConnected(
+          QIcon(renderSvgImage(makeSyncthingIcon(settings.disconnectedColor, StatusEmblem::Cross, settings.strokeWidth), settings.renderSize)))
     , isValid(true)
 {
 }
@@ -312,7 +321,8 @@ ForkAwesomeIcons::ForkAwesomeIcons(QtForkAwesome::Renderer &renderer, const QCol
     , shareAlt(renderer.pixmap(QtForkAwesome::Icon::ShareAlt, size, color))
     , refresh(renderer.pixmap(QtForkAwesome::Icon::Refresh, size, color))
     , clock(renderer.pixmap(QtForkAwesome::Icon::ClockO, size, color))
-    , exchangeAlt(renderer.pixmap(QtForkAwesome::Icon::Exchange, size, color))
+    , exclamation(renderer.pixmap(QtForkAwesome::Icon::Exclamation, size, color))
+    , exclamationCircle(renderer.pixmap(QtForkAwesome::Icon::ExclamationCircle, size, color))
     , exclamationTriangle(renderer.pixmap(QtForkAwesome::Icon::ExclamationTriangle, size, color))
     , cogs(renderer.pixmap(QtForkAwesome::Icon::Cogs, size, color))
     , link(renderer.pixmap(QtForkAwesome::Icon::Link, size, color))
@@ -322,30 +332,22 @@ ForkAwesomeIcons::ForkAwesomeIcons(QtForkAwesome::Renderer &renderer, const QCol
     , folder(renderer.pixmap(QtForkAwesome::Icon::Folder, size, color))
     , certificate(renderer.pixmap(QtForkAwesome::Icon::Certificate, size, color))
     , networkWired(renderer.pixmap(QtForkAwesome::Icon::Sitemap, size, color))
-    , cloudDownloadAlt(renderer.pixmap(QtForkAwesome::Icon::CloudDownload, size, color))
-    , cloudUploadAlt(renderer.pixmap(QtForkAwesome::Icon::CloudUpload, size, color))
+    , cloudDownload(renderer.pixmap(QtForkAwesome::Icon::CloudDownload, size, color))
+    , cloudUpload(renderer.pixmap(QtForkAwesome::Icon::CloudUpload, size, color))
     , tag(renderer.pixmap(QtForkAwesome::Icon::Tag, size, color))
     , exchange(renderer.pixmap(QtForkAwesome::Icon::Exchange, size, color))
+    , signal(renderer.pixmap(QtForkAwesome::Icon::Signal, size, color))
 {
 }
 
 IconManager::IconManager(const QPalette *palette)
-    : m_statusIcons()
+    : m_palette(palette ? *palette : QGuiApplication::palette())
+    , m_statusIcons()
     , m_trayIcons(m_statusIcons)
-    , m_commonForkAwesomeIcons(
-          m_forkAwesomeRenderer, (palette ? *palette : QGuiApplication::palette()).color(QPalette::Normal, QPalette::Text), QSize(64, 64))
+    , m_commonForkAwesomeIcons(m_forkAwesomeRenderer, m_palette.color(QPalette::Normal, QPalette::Text), QSize(64, 64))
     , m_distinguishTrayIcons(false)
 {
-#ifdef __GNUC__
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
-    if (!palette) {
-        QObject::connect(qGuiApp, &QGuiApplication::paletteChanged, this, &IconManager::setPalette);
-    }
-#ifdef __GNUC__
-#pragma GCC diagnostic pop
-#endif
+    m_forkAwesomeRenderer.warnIfInvalid();
 }
 
 void IconManager::applySettings(
@@ -411,6 +413,49 @@ void IconManager::renderForkAwesomeIcon(QtForkAwesome::Icon icon, QPainter *pain
     m_forkAwesomeRenderer.render(icon, painter, rect, m_palette.color(QPalette::Normal, QPalette::Text));
 }
 
+#ifdef Q_OS_ANDROID
+static QJniObject createBitmap(const QSize &size)
+{
+    const auto config = QJniObject::getStaticObjectField("android/graphics/Bitmap$Config", "ARGB_8888", "Landroid/graphics/Bitmap$Config;");
+    return QJniObject::callStaticObjectMethod("android/graphics/Bitmap", "createBitmap",
+        "(IILandroid/graphics/Bitmap$Config;)Landroid/graphics/Bitmap;", size.width(), size.height(), config.object());
+}
+
+QJniObject IconManager::makeAndroidBitmap(const QImage &img)
+{
+    auto size = img.size();
+    if (size.width() < 1 || size.height() < 1) {
+        return QJniObject();
+    }
+    auto image = img.format() == QImage::Format_RGBA8888 ? img : img.convertToFormat(QImage::Format_RGBA8888);
+    auto bitmap = createBitmap(size);
+    auto env = QJniEnvironment();
+    auto jniEnv = env.jniEnv();
+    auto info = AndroidBitmapInfo();
+    if (AndroidBitmap_getInfo(jniEnv, bitmap.object(), &info) != ANDROID_BITMAP_RESULT_SUCCESS || info.format != ANDROID_BITMAP_FORMAT_RGBA_8888) {
+        return QJniObject();
+    }
+    void *pixels;
+    if (AndroidBitmap_lockPixels(jniEnv, bitmap.object(), &pixels) != ANDROID_BITMAP_RESULT_SUCCESS) {
+        return QJniObject();
+    }
+    if (info.stride == static_cast<std::uint32_t>(image.bytesPerLine())) {
+        std::memcpy(pixels, image.constBits(), info.stride * info.height);
+    } else {
+        auto *bmpPtr = static_cast<uchar *>(pixels);
+        const auto width = std::min(info.width, static_cast<uint>(image.width()));
+        const auto height = std::min(info.height, static_cast<uint>(image.height()));
+        for (unsigned y = 0; y < height; y++, bmpPtr += info.stride) {
+            std::memcpy(bmpPtr, image.constScanLine(y), width);
+        }
+    }
+    if (AndroidBitmap_unlockPixels(jniEnv, bitmap.object()) != ANDROID_BITMAP_RESULT_SUCCESS) {
+        return QJniObject();
+    }
+    return bitmap;
+}
+#endif
+
 QString aboutDialogAttribution()
 {
     return QStringLiteral(
