@@ -4,42 +4,42 @@
 <context>
     <name>Data::StatusIconSettings</name>
     <message>
-        <location filename="../syncthingicons.cpp" line="232"/>
+        <location filename="../syncthingicons.cpp" line="239"/>
         <source>Misc. notifications</source>
         <translation>杂项通知</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="233"/>
+        <location filename="../syncthingicons.cpp" line="240"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="234"/>
+        <location filename="../syncthingicons.cpp" line="241"/>
         <source>Warning</source>
         <translation>警告</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="235"/>
+        <location filename="../syncthingicons.cpp" line="242"/>
         <source>Idle</source>
         <translation>空闲</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="236"/>
+        <location filename="../syncthingicons.cpp" line="243"/>
         <source>Scanning</source>
         <translation>扫描中</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="237"/>
+        <location filename="../syncthingicons.cpp" line="244"/>
         <source>Synchronizing</source>
         <translation>同步中</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="238"/>
+        <location filename="../syncthingicons.cpp" line="245"/>
         <source>Paused</source>
         <translation>已暂停</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="239"/>
+        <location filename="../syncthingicons.cpp" line="246"/>
         <source>Disconnected</source>
         <translation>已断连</translation>
     </message>
@@ -47,88 +47,101 @@
 <context>
     <name>Data::SyncthingDeviceModel</name>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="86"/>
-        <location filename="../syncthingdevicemodel.cpp" line="118"/>
+        <location filename="../syncthingdevicemodel.cpp" line="95"/>
+        <location filename="../syncthingdevicemodel.cpp" line="131"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="88"/>
+        <location filename="../syncthingdevicemodel.cpp" line="97"/>
         <source>Status</source>
         <translation>状态</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="120"/>
+        <location filename="../syncthingdevicemodel.cpp" line="133"/>
+        <source>Out of Sync items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingdevicemodel.cpp" line="139"/>
         <source>Address</source>
         <translation>地址</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="122"/>
+        <location filename="../syncthingdevicemodel.cpp" line="141"/>
         <source>Connection type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="124"/>
+        <location filename="../syncthingdevicemodel.cpp" line="143"/>
         <source>Last seen</source>
         <translation>最后在线</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="126"/>
+        <location filename="../syncthingdevicemodel.cpp" line="145"/>
         <source>Compression</source>
         <translation>压缩</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="128"/>
+        <location filename="../syncthingdevicemodel.cpp" line="147"/>
         <source>Certificate</source>
         <translation>证书</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="130"/>
+        <location filename="../syncthingdevicemodel.cpp" line="149"/>
         <source>Introducer</source>
         <translation>介绍人</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="132"/>
+        <location filename="../syncthingdevicemodel.cpp" line="135"/>
         <source>Incoming traffic</source>
         <translation>下载流量</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="134"/>
+        <location filename="../syncthingdevicemodel.cpp" line="137"/>
         <source>Outgoing traffic</source>
         <translation>上传流量</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="136"/>
+        <location filename="../syncthingdevicemodel.cpp" line="151"/>
         <source>Version</source>
         <translation>版本</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../syncthingdevicemodel.cpp" line="166"/>
+        <source>%1 item(s), ~ %2</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="157"/>
+        <location filename="../syncthingdevicemodel.cpp" line="183"/>
         <source>local</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="157"/>
+        <location filename="../syncthingdevicemodel.cpp" line="183"/>
         <source>remote</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="162"/>
+        <location filename="../syncthingdevicemodel.cpp" line="188"/>
         <source>unknown or this device</source>
         <translation>未知或本设备</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="167"/>
+        <location filename="../syncthingdevicemodel.cpp" line="164"/>
+        <location filename="../syncthingdevicemodel.cpp" line="193"/>
         <source>none</source>
         <translation>无</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="169"/>
+        <location filename="../syncthingdevicemodel.cpp" line="195"/>
         <source>yes</source>
         <translation>是</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="169"/>
+        <location filename="../syncthingdevicemodel.cpp" line="195"/>
         <source>no</source>
         <translation>否</translation>
     </message>
@@ -172,108 +185,143 @@
 <context>
     <name>Data::SyncthingDirectoryModel</name>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
-        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="96"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
         <source>ID</source>
         <translation>ID</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="98"/>
         <source>Status</source>
         <translation>状态</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
         <source>Path</source>
         <translation>路径</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
         <source>Global status</source>
         <translation>全局状态</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
         <source>Local status</source>
         <translation>本地状态</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
         <source>Shared with</source>
         <translation>分享到</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
         <source>Type</source>
         <translation>类型</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
         <source>Rescan interval</source>
         <translation>重新扫描间隔</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
         <source>Last scan</source>
         <translation>最后扫描</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="144"/>
         <source>Last file</source>
         <translation>最后更改</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
-        <source>Errors</source>
-        <translation>错误</translation>
+        <location filename="../syncthingdirectorymodel.cpp" line="394"/>
+        <source>Override remote changes</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="397"/>
+        <source>Revert local changes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Errors</source>
+        <translation type="vanished">错误</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdirectorymodel.cpp" line="171"/>
         <source>not shared</source>
         <translation>未分享</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
-        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="181"/>
         <source>unknown</source>
         <translation>未知</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="191"/>
         <source>none</source>
         <translation>无</translation>
     </message>
     <message numerus="yes">
-        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
         <source>%1 item(s) out of sync</source>
-        <translation>
+        <translation type="vanished">
             <numerusform>%1 项目未同步</numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
         <source>%1 and %2 item(s) out of sync</source>
-        <translation>
+        <translation type="vanished">
             <numerusform>%1 和  %2 项目未同步</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="278"/>
         <source>Deleted at %1</source>
         <translation>于 %1 被删除</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="281"/>
         <source>Updated at %1</source>
         <translation>于 %1 更新</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="148"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="293"/>
         <source>Failed items</source>
         <translation>已失败项目</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
+        <location filename="../syncthingdirectorymodel.cpp" line="146"/>
+        <source>Out of Sync items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
+        <source>%1 item(s), ~ %2</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../syncthingdirectorymodel.cpp" line="197"/>
+        <source>%1 item(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../syncthingdirectorymodel.cpp" line="199"/>
+        <source>%1 and %2 item(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../syncthingdirectorymodel.cpp" line="294"/>
         <source>Click for details</source>
         <translation>点击以获取详情</translation>
     </message>
@@ -341,12 +389,12 @@
 <context>
     <name>Data::SyncthingDownloadModel</name>
     <message>
-        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
+        <location filename="../syncthingdownloadmodel.cpp" line="95"/>
         <source>Dir/item</source>
         <translation>目录/项目</translation>
     </message>
     <message>
-        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
+        <location filename="../syncthingdownloadmodel.cpp" line="97"/>
         <source>Progress</source>
         <translation>进度</translation>
     </message>
@@ -367,158 +415,194 @@
 <context>
     <name>Data::SyncthingFileModel</name>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="291"/>
+        <location filename="../syncthingfilemodel.cpp" line="315"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="293"/>
+        <location filename="../syncthingfilemodel.cpp" line="317"/>
         <source>Size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="295"/>
+        <location filename="../syncthingfilemodel.cpp" line="319"/>
         <source>Last modified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="297"/>
+        <location filename="../syncthingfilemodel.cpp" line="321"/>
         <source>Ignore pattern</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="345"/>
+        <location filename="../syncthingfilemodel.cpp" line="369"/>
         <source>%1 elements</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="226"/>
+        <location filename="../syncthingfilemodel.cpp" line="232"/>
         <source>Exists locally and globally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="228"/>
+        <location filename="../syncthingfilemodel.cpp" line="234"/>
         <source>Exists only globally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="230"/>
+        <location filename="../syncthingfilemodel.cpp" line="236"/>
         <source>Exists only locally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="232"/>
+        <location filename="../syncthingfilemodel.cpp" line="238"/>
+        <source>Exists globally and perhaps locally</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="240"/>
+        <source>Exists locally and perhaps globally</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="242"/>
         <source>Does not exist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="462"/>
+        <location filename="../syncthingfilemodel.cpp" line="486"/>
         <source>Refresh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="465"/>
+        <location filename="../syncthingfilemodel.cpp" line="489"/>
         <source>Deselect recursively</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="465"/>
+        <location filename="../syncthingfilemodel.cpp" line="489"/>
         <source>Select recursively</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="467"/>
+        <location filename="../syncthingfilemodel.cpp" line="491"/>
         <source>Deselect single item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="467"/>
+        <location filename="../syncthingfilemodel.cpp" line="491"/>
         <source>Select single item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="469"/>
+        <location filename="../syncthingfilemodel.cpp" line="493"/>
         <source>Open local version</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="469"/>
+        <location filename="../syncthingfilemodel.cpp" line="493"/>
         <source>Copy local path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="469"/>
+        <location filename="../syncthingfilemodel.cpp" line="493"/>
         <source>Browse locally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="746"/>
+        <location filename="../syncthingfilemodel.cpp" line="778"/>
         <source>Select items to sync/ignore</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="752"/>
+        <location filename="../syncthingfilemodel.cpp" line="780"/>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="785"/>
         <source>Discard staged changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="762"/>
-        <source>Discard selection and staged changes</source>
+        <location filename="../syncthingfilemodel.cpp" line="795"/>
+        <source>Uncheck all and discard staged changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="775"/>
-        <source>Ignore selected items (and their children)</source>
+        <location filename="../syncthingfilemodel.cpp" line="797"/>
+        <source>Discard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="780"/>
-        <source>Include selected items (and their children)</source>
+        <location filename="../syncthingfilemodel.cpp" line="809"/>
+        <source>Ignore checked items (and their children)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <location filename="../syncthingfilemodel.cpp" line="823"/>
+        <source>Include checked items (and their children)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="862"/>
+        <source>Remove ignore patterns matching checked items (may affect other items as well)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="831"/>
         <source>Include all items by default</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <location filename="../syncthingfilemodel.cpp" line="816"/>
+        <source>Ignore and locally delete checked items (and their children)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="831"/>
         <source>Ignore all items by default</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="817"/>
-        <source>Remove ignore patterns matching against selected items (may affect other items as well)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="845"/>
+        <location filename="../syncthingfilemodel.cpp" line="890"/>
         <source>Review and apply staged changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="852"/>
+        <location filename="../syncthingfilemodel.cpp" line="892"/>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="900"/>
         <source>Do you want to apply the following changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="860"/>
+        <location filename="../syncthingfilemodel.cpp" line="908"/>
         <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="868"/>
+        <location filename="../syncthingfilemodel.cpp" line="916"/>
         <source>Unable to change ignore patterns:
 %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="882"/>
+        <location filename="../syncthingfilemodel.cpp" line="982"/>
         <source>Ignore patterns have been changed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="1057"/>
+        <location filename="../syncthingfilemodel.cpp" line="985"/>
+        <source>Ignore patterns have been changed but the following local files could not be deleted:
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="1155"/>
         <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -559,32 +643,37 @@
 <context>
     <name>Data::SyncthingStatusComputionModel</name>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="38"/>
         <source>Local dir is scanning</source>
         <translation>正在扫描本地目录</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="40"/>
         <source>Local dir is synchronizing</source>
         <translation>正在同步本地目录</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="42"/>
         <source>Remote dir has outstanding progress</source>
         <translation>远程目录有未完成进度</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="44"/>
+        <source>No remote device connected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="46"/>
         <source>A device is paused</source>
         <translation>一个设备已暂停</translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="48"/>
         <source>Local dir is out of sync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
+        <location filename="../syncthingstatuscomputionmodel.cpp" line="50"/>
         <source>Unread notification present</source>
         <translation type="unfinished"></translation>
     </message>
