@@ -56,7 +56,7 @@ void StatusInfo::updateConnectionStatus(const SyncthingConnection &connection, c
         m_statusIcon = &icons.disconnected;
         break;
     default:
-        if ((connection.statusComputionFlags() & SyncthingStatusComputionFlags::OutOfSync) && connection.hasOutOfSyncDirs()) {
+        if ((connection.statusComputionFlags() && SyncthingStatusComputionFlags::OutOfSync) && connection.hasOutOfSyncDirs()) {
             switch (connection.status()) {
             case SyncthingStatus::Synchronizing:
                 m_statusText = QCoreApplication::translate("QtGui::StatusInfo", "Synchronization is ongoing");
@@ -67,7 +67,7 @@ void StatusInfo::updateConnectionStatus(const SyncthingConnection &connection, c
                 m_statusText = QCoreApplication::translate("QtGui::StatusInfo", "At least one folder is out of sync");
                 m_statusIcon = &icons.error;
             }
-        } else if (connection.hasErrors() && (connection.statusComputionFlags() & SyncthingStatusComputionFlags::UnreadNotifications)) {
+        } else if (connection.hasErrors() && (connection.statusComputionFlags() && SyncthingStatusComputionFlags::UnreadNotifications)) {
             m_statusText = QCoreApplication::translate("QtGui::StatusInfo", "Notifications available");
             m_statusIcon = &icons.notify;
         } else {
@@ -92,6 +92,10 @@ void StatusInfo::updateConnectionStatus(const SyncthingConnection &connection, c
                 m_statusText = QCoreApplication::translate("QtGui::StatusInfo", "At least one remote folder is not in sync");
                 m_statusIcon = &icons.sync;
                 break;
+            case SyncthingStatus::NoRemoteConnected:
+                m_statusText = QCoreApplication::translate("QtGui::StatusInfo", "No remote device connected");
+                m_statusIcon = &icons.noRemoteConnected;
+                break;
             default:
                 m_statusText = QCoreApplication::translate("QtGui::StatusInfo", "Status is unknown");
                 m_statusIcon = &icons.disconnected;
