@@ -3,10 +3,13 @@
 #include <syncthingconnector/syncthingconnection.h>
 #include <syncthingconnector/utils.h>
 
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS)
 #include "../settings/settings.h"
+#endif
 
 #include <c++utilities/io/ansiescapecodes.h>
 
+#include <QMetaObject>
 #include <QtConcurrentRun>
 
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
@@ -18,6 +21,7 @@
 #include <iostream>
 #include <limits>
 #include <string_view>
+#include <utility>
 
 using namespace std;
 using namespace std::placeholders;
@@ -33,7 +37,11 @@ SyncthingLauncher *SyncthingLauncher::s_mainInstance = nullptr;
  * \remarks
  * - This is *not* strictly a singleton class. However, one instance is supposed to be the "main instance" (see SyncthingLauncher::setMainInstance()).
  * - A SyncthingLauncher instance can only launch one Syncthing instance at a time.
- * - Using Syncthing as library is still under development and must be explicitly enabled by setting the CMake variable USE_LIBSYNCTHING.
+ * - Using Syncthing as library must be explicitly enabled by setting the CMake variable USE_LIBSYNCTHING.
+ * - When using Syncthing as library only one instance of SyncthingLauncher can start Syncthing at a time; trying to start a 2nd Syncthing instance
+ *   via another SyncthingLauncher will leads to a failure (but not to undefined behavior).
+ * - You must not try to Syncthing as library from multiple threads at the same time. This will lead to undefined behavior even when using different
+ *   SyncthingLauncher instances.
  */
 
 /*!
@@ -41,7 +49,9 @@ SyncthingLauncher *SyncthingLauncher::s_mainInstance = nullptr;
  */
 SyncthingLauncher::SyncthingLauncher(QObject *parent)
     : QObject(parent)
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS)
     , m_lastLauncherSettings(nullptr)
+#endif
     , m_relevantConnection(nullptr)
     , m_guiListeningUrlSearch("Access the GUI via the following URL: ", "\n\r", std::string_view(), BufferSearch::CallbackType())
     , m_exitSearch("Syncthing exited: ", "\n\r", std::string_view(), BufferSearch::CallbackType())
@@ -60,6 +70,9 @@ SyncthingLauncher::SyncthingLauncher(QObject *parent)
     connect(&m_process, &SyncthingProcess::stateChanged, this, &SyncthingLauncher::handleProcessStateChanged, Qt::QueuedConnection);
     connect(&m_process, &SyncthingProcess::errorOccurred, this, &SyncthingLauncher::errorOccurred, Qt::QueuedConnection);
     connect(&m_process, &SyncthingProcess::confirmKill, this, &SyncthingLauncher::confirmKill);
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+    connect(&m_startWatcher, &QFutureWatcher<std::int64_t>::finished, this, &SyncthingLauncher::handleLibSyncthingFinished);
+#endif
 
     // initialize handling of metered connections
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
@@ -70,6 +83,19 @@ SyncthingLauncher::SyncthingLauncher(QObject *parent)
 #endif
 }
 
+/*!
+ * \brief Ensures the built-in Syncthing instance is stopped if it was started by this SyncthingLauncher instance.
+ */
+SyncthingLauncher::~SyncthingLauncher()
+{
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+    if (!m_startFuture.isCanceled()) {
+        stopLibSyncthing();
+        m_startFuture.waitForFinished();
+    }
+#endif
+}
+
 #ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
 /*!
  * \brief Sets whether Syncthing is supposed to run or not.
@@ -92,7 +118,9 @@ void SyncthingLauncher::setRunning(bool running, LibSyncthing::RuntimeOptions &&
         tearDownLibSyncthing();
     }
     // save runtime options so Syncthing can resume in case runtime conditions allow it
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS)
     m_lastLauncherSettings = nullptr;
+#endif
     m_lastRuntimeOptions = std::move(runtimeOptions);
     // emit signal in any case (even if there's no change) so runningStatus() is re-evaluated
     emit runningChanged(shouldBeRunning);
@@ -108,6 +136,8 @@ QString SyncthingLauncher::runningStatus() const
         return tr("Syncthing is running");
     } else if (m_stoppedMetered) {
         return tr("Syncthing is temporarily stopped due to metered connection");
+    } else if (m_lastExitStatus.has_value()) {
+        return tr("Syncthing exited with status %1").arg(m_lastExitStatus.value().code);
     } else {
         return tr("Syncthing is not running");
     }
@@ -153,13 +183,19 @@ void SyncthingLauncher::setNetworkConnectionMetered(std::optional<bool> metered)
             if (metered.value_or(false)) {
                 terminateDueToMeteredConnection();
             } else if (!metered.value_or(true) && m_stoppedMetered) {
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS)
                 if (m_lastLauncherSettings) {
                     launch(*m_lastLauncherSettings);
-#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
-                } else if (m_lastRuntimeOptions) {
-                    launch(*m_lastRuntimeOptions);
-#endif
                 }
+#endif
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS) && defined(SYNCTHINGWIDGETS_USE_LIBSYNCTHING)
+                else
+#endif
+#if defined(SYNCTHINGWIDGETS_USE_LIBSYNCTHING)
+                    if (m_lastRuntimeOptions) {
+                    launch(*m_lastRuntimeOptions);
+                }
+#endif
             }
         }
         emit networkConnectionMeteredChanged(metered);
@@ -171,7 +207,8 @@ void SyncthingLauncher::setNetworkConnectionMetered(std::optional<bool> metered)
  */
 void SyncthingLauncher::setStoppingOnMeteredConnection(bool stopOnMeteredConnection)
 {
-    if ((stopOnMeteredConnection != m_stopOnMeteredConnection) && (m_stopOnMeteredConnection = stopOnMeteredConnection) && m_metered) {
+    if ((stopOnMeteredConnection != m_stopOnMeteredConnection) && (m_stopOnMeteredConnection = stopOnMeteredConnection)
+        && m_metered.value_or(false)) {
         terminateDueToMeteredConnection();
     }
 }
@@ -222,13 +259,13 @@ void SyncthingLauncher::launch(const QString &program, const QStringList &argume
     }
 
 #ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
-    // use libsyncthing
-    m_startFuture = QtConcurrent::run(std::bind(&SyncthingLauncher::runLibSyncthing, this, LibSyncthing::RuntimeOptions{}));
+    runLibSyncthing(LibSyncthing::RuntimeOptions{});
 #else
     showLibSyncthingNotSupported();
 #endif
 }
 
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS)
 /*!
  * \brief Launches a Syncthing instance according to the specified \a launcherSettings.
  * \remarks Does nothing if already running an instance.
@@ -265,8 +302,49 @@ void SyncthingLauncher::launch(const Settings::Launcher &launcherSettings)
     m_lastRuntimeOptions.reset();
 #endif
 }
+#endif
 
 #ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+/*!
+ * \brief Returns the specified \a logLevel for the built-in Syncthing instance as string.
+ */
+QString SyncthingLauncher::libSyncthingLogLevelString(LibSyncthing::LogLevel logLevel)
+{
+    switch (logLevel) {
+    case LibSyncthing::LogLevel::Debug:
+        return QStringLiteral("debug");
+    case LibSyncthing::LogLevel::Verbose:
+        return QStringLiteral("verbose");
+    case LibSyncthing::LogLevel::Warning:
+        return QStringLiteral("warning");
+    case LibSyncthing::LogLevel::Fatal:
+        return QStringLiteral("fatal");
+    default:
+        return QStringLiteral("info");
+    }
+}
+
+/*!
+ * \brief Sets the log level for the built-in Syncthing instance from the specified string.
+ * \remarks Assigns \a fallbackLogLevel if \a logLevel is not valid.
+ */
+void SyncthingLauncher::setLibSyncthingLogLevel(const QString &logLevel, LibSyncthing::LogLevel fallbackLogLevel)
+{
+    if (logLevel.compare(QLatin1String("debug"), Qt::CaseInsensitive) == 0) {
+        m_libsyncthingLogLevel = LibSyncthing::LogLevel::Debug;
+    } else if (logLevel.compare(QLatin1String("verbose"), Qt::CaseInsensitive) == 0) {
+        m_libsyncthingLogLevel = LibSyncthing::LogLevel::Verbose;
+    } else if (logLevel.compare(QLatin1String("info"), Qt::CaseInsensitive) == 0) {
+        m_libsyncthingLogLevel = LibSyncthing::LogLevel::Info;
+    } else if (logLevel.compare(QLatin1String("warning"), Qt::CaseInsensitive) == 0) {
+        m_libsyncthingLogLevel = LibSyncthing::LogLevel::Warning;
+    } else if (logLevel.compare(QLatin1String("fatal"), Qt::CaseInsensitive) == 0) {
+        m_libsyncthingLogLevel = LibSyncthing::LogLevel::Fatal;
+    } else {
+        m_libsyncthingLogLevel = fallbackLogLevel;
+    }
+}
+
 /*!
  * \brief Launches a Syncthing instance using the internal library with the specified \a runtimeOptions.
  * \remarks
@@ -281,7 +359,7 @@ void SyncthingLauncher::launch(const LibSyncthing::RuntimeOptions &runtimeOption
         return;
     }
     resetState();
-    m_startFuture = QtConcurrent::run(std::bind(&SyncthingLauncher::runLibSyncthing, this, runtimeOptions));
+    runLibSyncthing(runtimeOptions);
 }
 #endif
 
@@ -332,13 +410,18 @@ void SyncthingLauncher::stopLibSyncthing()
 {
 #ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
     LibSyncthing::stopSyncthing();
-    // no need to emit exited/runningChanged here; that is already done in runLibSyncthing()
+    // no need to emit exited/runningChanged here; that is already done after
+    // m_startFuture has finished
 #endif
 }
 
 void SyncthingLauncher::handleProcessReadyRead()
 {
-    handleOutputAvailable(m_process.readAll());
+    const auto data = m_process.readAll();
+    if (m_logFile.isOpen()) {
+        m_logFile.write(data);
+    }
+    handleOutputAvailable(-1, data);
 }
 
 void SyncthingLauncher::handleProcessStateChanged(QProcess::ProcessState newState)
@@ -346,17 +429,20 @@ void SyncthingLauncher::handleProcessStateChanged(QProcess::ProcessState newStat
     switch (newState) {
     case QProcess::NotRunning:
         emit runningChanged(false);
+        emit startingChanged();
         break;
     case QProcess::Starting:
         emit runningChanged(true);
+        emit startingChanged();
         break;
     default:;
     }
 }
 
-void SyncthingLauncher::handleProcessFinished(int exitCode, QProcess::ExitStatus exitStatus)
+void SyncthingLauncher::handleProcessFinished(int code, QProcess::ExitStatus status)
 {
-    emit exited(exitCode, exitStatus);
+    const auto &exitStatus = m_lastExitStatus.emplace(code, status);
+    emit exited(exitStatus.code, exitStatus.status);
 }
 
 void SyncthingLauncher::resetState()
@@ -367,6 +453,7 @@ void SyncthingLauncher::resetState()
     m_relevantConnection = nullptr;
     m_guiListeningUrlSearch.reset();
     m_exitSearch.reset();
+    m_lastExitStatus.reset();
     if (!m_guiListeningUrl.isEmpty()) {
         m_guiListeningUrl.clear();
         emit guiUrlChanged(m_guiListeningUrl);
@@ -384,21 +471,25 @@ static const char *const logLevelStrings[] = {
 
 void SyncthingLauncher::handleLoggingCallback(LibSyncthing::LogLevel level, const char *message, size_t messageSize)
 {
-    if (level < m_libsyncthingLogLevel) {
-        return;
-    }
-    QByteArray messageData;
+    auto messageData = QByteArray();
     messageSize = min<size_t>(numeric_limits<int>::max() - 20, messageSize);
     messageData.reserve(static_cast<int>(messageSize) + 20);
     messageData.append(logLevelStrings[static_cast<int>(level)]);
     messageData.append(message, static_cast<int>(messageSize));
     messageData.append('\n');
-
-    handleOutputAvailable(std::move(messageData));
+    if (level >= m_libsyncthingLogLevel && m_logFile.isOpen()) {
+        m_logFile.write(messageData);
+    }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+    QMetaObject::invokeMethod(this, &SyncthingLauncher::handleOutputAvailable, Qt::QueuedConnection, static_cast<int>(level), std::move(messageData));
+#else
+    QMetaObject::invokeMethod(
+        this, "handleOutputAvailable", Qt::QueuedConnection, Q_ARG(int, static_cast<int>(level)), Q_ARG(QByteArray, messageData));
+#endif
 }
 #endif
 
-void SyncthingLauncher::handleOutputAvailable(QByteArray &&data)
+void SyncthingLauncher::handleOutputAvailable(int logLevel, const QByteArray &data)
 {
     const auto *const exitOffset = m_exitSearch.process(data.data(), static_cast<std::size_t>(data.size()));
     const auto *const guiAddressOffset = m_guiListeningUrlSearch.process(data.data(), static_cast<std::size_t>(data.size()));
@@ -412,10 +503,18 @@ void SyncthingLauncher::handleOutputAvailable(QByteArray &&data)
         std::cerr << EscapeCodes::Phrases::Info << "Syncthing GUI available: " << m_guiListeningUrlSearch.result() << EscapeCodes::Phrases::End;
         m_guiListeningUrlSearch.reset();
         emit guiUrlChanged(m_guiListeningUrl);
+        emit startingChanged();
     } else if (exitOffset) {
         m_guiListeningUrl.clear();
         emit guiUrlChanged(m_guiListeningUrl);
     }
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+    if (logLevel < static_cast<int>(m_libsyncthingLogLevel)) {
+        return;
+    }
+#else
+    Q_UNUSED(logLevel)
+#endif
     if (isEmittingOutput()) {
         emit outputAvailable(data);
     } else {
@@ -431,30 +530,53 @@ void SyncthingLauncher::terminateDueToMeteredConnection()
         // running before)
         return;
     }
+#if defined(SYNCTHINGWIDGETS_GUI_QTWIDGETS)
     if (m_lastLauncherSettings && !m_relevantConnection) {
         m_relevantConnection = m_lastLauncherSettings->connectionForLauncher(this);
     }
+#endif
     terminate(m_relevantConnection);
     m_stoppedMetered = true;
 }
 
 #ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+/*!
+ * \brief Starts the built-in Syncthing instance.
+ * \remarks Returns immediately as Syncthing is started in a different thread.
+ */
 void SyncthingLauncher::runLibSyncthing(const LibSyncthing::RuntimeOptions &runtimeOptions)
 {
-    LibSyncthing::setLoggingCallback(bind(&SyncthingLauncher::handleLoggingCallback, this, _1, _2, _3));
+    if (LibSyncthing::hasLoggingCallback()) {
+        showLibSyncthingNotSupported(QByteArrayLiteral("libsyncthing has already been started"));
+        return;
+    }
+    LibSyncthing::setLoggingCallback(std::bind(&SyncthingLauncher::handleLoggingCallback, this, _1, _2, _3));
     emit runningChanged(true);
-    const auto exitCode = LibSyncthing::runSyncthing(runtimeOptions);
+    emit startingChanged();
+    m_startWatcher.setFuture(m_startFuture = QtConcurrent::run(std::bind(&LibSyncthing::runSyncthing, runtimeOptions)));
+}
+
+void SyncthingLauncher::handleLibSyncthingFinished()
+{
+    const auto exitCode = m_startFuture.result();
+    const auto &exitStatus = m_lastExitStatus.emplace(static_cast<int>(exitCode), exitCode == 0 ? QProcess::NormalExit : QProcess::CrashExit);
+    LibSyncthing::setLoggingCallback(LibSyncthing::LoggingCallback());
     m_guiListeningUrl.clear();
     emit guiUrlChanged(m_guiListeningUrl);
-    emit exited(static_cast<int>(exitCode), exitCode == 0 ? QProcess::NormalExit : QProcess::CrashExit);
+    emit exited(exitStatus.code, exitStatus.status);
     emit runningChanged(false);
-}
-#else
-void SyncthingLauncher::showLibSyncthingNotSupported()
-{
-    handleOutputAvailable(QByteArrayLiteral("libsyncthing support not enabled"));
-    emit exited(-1, QProcess::CrashExit);
+    emit startingChanged();
 }
 #endif
 
+/*!
+ * \brief Shows that launching Syncthing is not supported by emitting a non-zero exit status and logging \a reason.
+ */
+void SyncthingLauncher::showLibSyncthingNotSupported(QByteArray &&reason)
+{
+    handleOutputAvailable(4, std::move(reason)); // LibSyncthing::LogLevel::Fatal
+    const auto &exitStatus = m_lastExitStatus.emplace(-1, QProcess::CrashExit);
+    emit exited(exitStatus.code, exitStatus.status);
+}
+
 } // namespace Data
