@@ -536,6 +536,7 @@ bool AppearanceOptionPage::apply()
     settings.trayMenuSize.setWidth(ui()->widthSpinBox->value());
     settings.trayMenuSize.setHeight(ui()->heightSpinBox->value());
     settings.showTraffic = ui()->showTrafficCheckBox->isChecked();
+    settings.showDownloads = ui()->showDownloadsCheckBox->isChecked();
     settings.showTabTexts = ui()->showTabTextsCheckBox->isChecked();
     v.icons.preferIconsFromTheme = ui()->preferIconsFromThemeCheckBox->isChecked();
     int style;
@@ -588,6 +589,7 @@ void AppearanceOptionPage::reset()
     resetPositioningSettings();
     ui()->windowTypeComboBox->setCurrentIndex(settings.windowType);
     ui()->showTrafficCheckBox->setChecked(settings.showTraffic);
+    ui()->showDownloadsCheckBox->setChecked(settings.showDownloads);
     ui()->showTabTextsCheckBox->setChecked(settings.showTabTexts);
     ui()->preferIconsFromThemeCheckBox->setChecked(v.icons.preferIconsFromTheme);
     auto index = int();
@@ -748,7 +750,7 @@ QWidget *IconsOptionPage::setupWidget()
             label->setText(QString::number(value) + QStringLiteral(" px"));
         } else {
             label->setText(QCoreApplication::translate("QtGui::IconsOptionPageBase", "%1 px (scaled to %2 px)")
-                               .arg(QString::number(value), QString::number(static_cast<qreal>(value) * scaleFactor, 'f', 0)));
+                    .arg(QString::number(value), QString::number(static_cast<qreal>(value) * scaleFactor, 'f', 0)));
         }
     });
 
@@ -1096,7 +1098,7 @@ void AutostartOptionPage::reset()
         ui()->pathWarningLabel->setText(QCoreApplication::translate("QtGui::AutostartOptionPage",
             "There is already an autostart entry for \"%1\". "
             "It will not be overridden when applying changes unless you delete it first.")
-                                            .arg(configuredPath.value()));
+                .arg(configuredPath.value()));
     }
 }
 
@@ -1147,6 +1149,12 @@ QWidget *LauncherOptionPage::setupWidget()
         ui()->stopOnMeteredCheckBox->setVisible(false);
     }
 
+    // set placeholder texts in path selections
+    for (auto *const pathSelection :
+        std::initializer_list<QtUtilities::PathSelection *>{ ui()->configDirPathSelection, ui()->dataDirPathSelection }) {
+        pathSelection->lineEdit()->setPlaceholderText(tr("Leave empty for default path"));
+    }
+
     // hide libsyncthing-controls by default (as the checkbox is unchecked by default)
     for (auto *const lstWidget : std::initializer_list<QWidget *>{ ui()->configDirLabel, ui()->configDirPathSelection, ui()->dataDirLabel,
              ui()->dataDirPathSelection, ui()->logLevelLabel, ui()->logLevelComboBox, ui()->optionsLabel, ui()->expandEnvCheckBox }) {
