@@ -5,13 +5,19 @@
 
 #include "../webview/webviewdefs.h"
 
+#if !QT_CONFIG(process)
+#include <syncthingconnector/syncthingprocess.h>
+#endif
+
 #include <syncthingmodel/syncthingicons.h>
 
 #include <qtutilities/settingsdialog/optionpage.h>
 #include <qtutilities/settingsdialog/qtsettings.h>
 #include <qtutilities/settingsdialog/settingsdialog.h>
 
+#if QT_CONFIG(process)
 #include <QProcess>
+#endif
 #include <QStringList>
 #include <QWidget>
 
@@ -99,6 +105,8 @@ private:
 void update(bool preserveSize = false);
 Context m_context;
 Data::StatusIconSettings m_settings;
+QAction *m_paletteAction = nullptr;
+bool m_usePalette = false;
 struct {
     QtUtilities::ColorButton *colorButtons[3] = {};
     QLabel *previewLabel = nullptr;
