@@ -326,6 +326,7 @@ void WizardTests::testConfiguringLauncher()
             case Data::SyncthingStatus::Scanning:
             case Data::SyncthingStatus::Synchronizing:
             case Data::SyncthingStatus::RemoteNotInSync:
+            case Data::SyncthingStatus::NoRemoteConnected:
             case Data::SyncthingStatus::Paused:
                 qDebug() << "connected to Syncthing: " << m_connection.statusText();
             default:;
@@ -466,6 +467,7 @@ void WizardTests::testConfiguringCurrentlyRunningSyncthing()
 
     // apply changes and wait for results on final wizard page
     auto &settings = Settings::values();
+    settings.connection.primary.syncthingUrl = QStringLiteral("foobar"); // ensure this value will change so we always get a backup
     auto waitForCfg = std::function<void(void)>();
     FinalWizardPage *finalPage = nullptr;
     QProgressBar *progressBar = nullptr;
