@@ -9,14 +9,10 @@
 #include <qtforkawesome/icon.h>
 #include <qtforkawesome/renderer.h>
 
-#include <QApplication>
-#include <QBrush>
 #include <QPainter>
 #include <QPalette>
-#include <QPixmap>
 #include <QStyle>
 #include <QStyleOptionViewItem>
-#include <QTextOption>
 
 using namespace Data;
 
@@ -32,30 +28,22 @@ void DevButtonsItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem
     auto opt = option;
     initStyleOption(&opt, index);
     opt.viewItemPosition = QStyleOptionViewItem::OnlyOne;
+
     if (index.parent().isValid()) {
-        QStyledItemDelegate::paint(painter, opt, index);
+        drawField(this, painter, opt, index, SyncthingDeviceModel::DeviceDetail);
     } else {
-        // init style options to use drawControl(), except for the text
-        opt.text.clear();
-        opt.features = QStyleOptionViewItem::None;
-        drawBasicItemViewItem(*painter, opt);
+        drawIdAndStatus(this, painter, opt, index, SyncthingDeviceModel::DeviceStatusString, SyncthingDeviceModel::DeviceStatusColor,
+            listItemIconsSize(0) + listItemSpacing);
 
-        // draw text
-        QRectF textRect = option.rect;
-        textRect.setWidth(textRect.width() - 20);
-        QTextOption textOption;
-        textOption.setAlignment(opt.displayAlignment);
-        setupPainterToDrawViewItemText(painter, opt);
-        painter->drawText(textRect, displayText(index.data(Qt::DisplayRole), option.locale), textOption);
-
-        // draw buttons
+        // draw button
         if (index.data(SyncthingDeviceModel::IsThisDevice).toBool()) {
             return;
         }
-        const int buttonY = option.rect.y() + centerObj(option.rect.height(), 16);
+        const int buttonY = option.rect.y() + centerObj(option.rect.height(), listItemIconSize);
         QtForkAwesome::Renderer::global().render(
             index.data(SyncthingDeviceModel::DevicePaused).toBool() ? QtForkAwesome::Icon::Play : QtForkAwesome::Icon::Pause, painter,
-            QRect(option.rect.right() - 16, buttonY, 16, 16), QGuiApplication::palette().color(QPalette::Text));
+            QRect(option.rect.right() - listItemIconsSize(0), buttonY, listItemIconSize, listItemIconSize),
+            QGuiApplication::palette().color(QPalette::Text));
     }
 }
 } // namespace QtGui
