@@ -22,8 +22,7 @@ DirView::DirView(QWidget *parent)
 {
     header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     header()->hide();
-    setItemDelegate(new UnifiedItemDelegate(this));
-    setItemDelegateForColumn(1, new DirButtonsItemDelegate(this));
+    setItemDelegate(new DirButtonsItemDelegate(this));
     connect(this, &BasicTreeView::customContextMenuRequested, this, &DirView::showContextMenu);
 }
 
@@ -43,19 +42,19 @@ void DirView::mouseReleaseEvent(QMouseEvent *event)
     if (!clickedRow.index.parent().isValid()) {
         // open/scan dir buttons
         const QRect itemRect = visualRect(clickedRow.proxyIndex);
-        if (pos.x() <= itemRect.right() - 58) {
+        if (pos.x() <= itemRect.right() - (listItemIconsSize(2) + listItemSpacing / 2)) {
             return;
         }
-        if (pos.x() < itemRect.right() - 34) {
+        if (pos.x() < itemRect.right() - (listItemIconsSize(1) + listItemIconSpacing / 2)) {
             if (!clickedRow.data->paused) {
                 emit scanDir(*clickedRow.data);
             }
-        } else if (pos.x() < itemRect.right() - 17) {
+        } else if (pos.x() < itemRect.right() - (listItemIconsSize(0) + listItemIconSpacing / 2)) {
             emit pauseResumeDir(*clickedRow.data);
         } else {
             emit openDir(*clickedRow.data);
         }
-    } else if (clickedRow.index.row() == 9 && clickedRow.data->pullErrorCount) {
+    } else if (clickedRow.index.row() == 10 && clickedRow.data->pullErrorCount) {
         auto &connection(*clickedRow.model->connection());
         connection.requestDirPullErrors(clickedRow.data->id);
 
