@@ -9,7 +9,7 @@ namespace QtGui {
 class DownloadItemDelegate : public QStyledItemDelegate {
     Q_OBJECT
 public:
-    DownloadItemDelegate(QObject *parent);
+    explicit DownloadItemDelegate(QObject *parent);
 
     void paint(QPainter *, const QStyleOptionViewItem &, const QModelIndex &) const override;
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
