@@ -381,7 +381,7 @@ void TrayWidget::showOwnDeviceId()
 
 void TrayWidget::showLog()
 {
-    auto *const dlg = TextViewDialog::forLogEntries(m_connection);
+    auto *const dlg = TextViewDialog::forLogEntries(m_connection, this);
     dlg->setAttribute(Qt::WA_DeleteOnClose, true);
     showDialog(dlg, centerWidgetAvoidingOverflow(dlg));
 }
@@ -483,6 +483,7 @@ void TrayWidget::handleStatusChanged(SyncthingStatus status)
     case SyncthingStatus::Scanning:
     case SyncthingStatus::Synchronizing:
     case SyncthingStatus::RemoteNotInSync:
+    case SyncthingStatus::NoRemoteConnected:
         m_ui->statusPushButton->setText(tr("Pause"));
         m_ui->statusPushButton->setToolTip(tr("Syncthing is running, click to pause all devices"));
         m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("pause.fa")));
@@ -603,14 +604,13 @@ void TrayWidget::applySettings(const QString &connectionConfig)
             }
         }
     }
+    m_ui->tabWidget->setTabVisible(3, settings.appearance.showDownloads);
     if (m_menu) {
         m_menu->setWindowType(settings.appearance.windowType);
     }
 
     // update status icon and text of tray icon because reconnect interval might have changed
-    if (m_menu && m_menu->icon()) {
-        m_menu->icon()->updateStatusIconAndText();
-    }
+    updateIconAndTooltip();
 
     // show warning when explicitly specified connection configuration was not found
     if (!specifiedConnectionConfigFound && !connectionConfig.isEmpty()) {
@@ -630,18 +630,19 @@ bool TrayWidget::event(QEvent *event)
 {
     const auto res = QWidget::event(event);
     switch (event->type()) {
-    case QEvent::PaletteChange:
+    case QEvent::PaletteChange: {
+        const auto palette = QPalette();
+        IconManager::instance(&palette).setPalette(palette);
         setBrightColorsOfModelsAccordingToPalette();
         setLabelPixmaps();
         setTrafficPixmaps(true);
         break;
+    }
     case QEvent::LanguageChange:
         m_ui->retranslateUi(this);
         applyLauncherSettings(false, true, false);
         handleStatusChanged(m_connection.status());
-        if (m_menu && m_menu->icon()) {
-            m_menu->icon()->updateStatusIconAndText();
-        }
+        updateIconAndTooltip();
         break;
 #if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
     case QEvent::DevicePixelRatioChange:
@@ -791,6 +792,7 @@ void TrayWidget::changeStatus()
     case SyncthingStatus::Scanning:
     case SyncthingStatus::Synchronizing:
     case SyncthingStatus::RemoteNotInSync:
+    case SyncthingStatus::NoRemoteConnected:
         m_connection.pauseAllDevs();
         break;
     case SyncthingStatus::Paused:
@@ -985,9 +987,7 @@ void TrayWidget::handleConnectionSelected(QAction *connectionAction)
 void TrayWidget::handleNewErrors()
 {
     m_ui->notificationsPushButton->setVisible(m_connection.hasErrors());
-    if (m_menu && m_menu->icon()) {
-        m_menu->icon()->updateStatusIconAndText();
-    }
+    updateIconAndTooltip();
 }
 
 void TrayWidget::concludeWizard(const QString &errorMessage)
