@@ -77,7 +77,6 @@ public Q_SLOTS:
         const QByteArray &response);
     void showInternalErrorsButton();
     void showInternalErrorsDialog();
-    void dismissNotifications();
     void restartSyncthing();
     void quitTray();
     void applySettings(const QString &connectionConfig = QString());
@@ -86,6 +85,8 @@ public Q_SLOTS:
 
 protected:
     bool event(QEvent *event) override;
+    void showEvent(QShowEvent *event) override;
+    void hideEvent(QHideEvent *event) override;
 
 private Q_SLOTS:
     void handleStatusChanged(Data::SyncthingStatus status);
@@ -98,6 +99,7 @@ private Q_SLOTS:
     void browseRemoteFiles(const Data::SyncthingDir &dir);
     void showIgnorePatterns(const Data::SyncthingDir &dir);
     void showRecentChangesContextMenu(const QPoint &position);
+    void handleCurrentTabChanged(int index);
     void changeStatus();
     void updateTraffic();
     bool updateTrafficText();
@@ -105,6 +107,7 @@ private Q_SLOTS:
     void updateIconAndTooltip();
     void toggleRunning();
     Settings::Launcher::LauncherStatus handleLauncherStatusChanged();
+    Settings::Launcher::LauncherStatus handleLauncherGuiAddressChanged(const QUrl &guiAddress);
     Settings::Launcher::LauncherStatus applyLauncherSettings(
         bool reconnectRequired = false, bool skipApplyingToConnection = false, bool skipStartStopButton = false);
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
@@ -112,8 +115,9 @@ private Q_SLOTS:
     Settings::Systemd::ServiceStatus applySystemdSettings(bool reconnectRequired = false);
 #endif
     void handleWebViewDeleted();
-    void handleNewNotification(CppUtilities::DateTime when, const QString &msg);
+    void handleNotificationsDialogDeleted();
     void handleConnectionSelected(QAction *connectionAction);
+    void handleNewErrors();
     void concludeWizard(const QString &errorMessage = QString());
     void showDialog(QWidget *dlg, bool maximized = false);
     void showCenteredDialog(QWidget *dlg, const QSize &size);
@@ -128,6 +132,7 @@ private:
     static Wizard *s_wizard;
     static QtUtilities::AboutDialog *s_aboutDlg;
     WebViewDialog *m_webViewDlg;
+    QDialog *m_notificationsDlg;
     QFrame *m_cornerFrame;
     QPushButton *m_internalErrorsButton;
     Data::SyncthingConnection m_connection;
@@ -142,7 +147,6 @@ private:
     QActionGroup *m_connectionsActionGroup;
     Data::SyncthingConnectionSettings *m_selectedConnection;
     QMenu *m_notificationsMenu;
-    std::vector<Data::SyncthingLogEntry> m_notifications;
     enum class StartStopButtonTarget { None, Service, Launcher } m_startStopButtonTarget;
     QStringList m_tabTexts;
     struct {
